.. _github-stats:

GitHub Stats
============

GitHub stats for 2015/10/29 - 2017/05/09 (tag: v1.5.0)

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 1130 issues and merged 1003 pull requests.

The following 292 authors contributed 4014 commits.

* 4over7
* Aashil Patel
* AbdealiJK
* Acanthostega
* Adam
* Adam Williamson
* Adrian Price-Whelan
* Adrien Chardon
* Adrien F. Vincent
* Alan Bernstein
* Alberto
* alcinos
* Aleksey Bilogur
* Alex Rothberg
* Alexander Buchkovsky
* Alexis Bienvenüe
* Ali Uneri
* Alvaro Sanchez
* alvarosg
* AndersonDaniel
* Andreas Hilboll
* Andreas Mayer
* aneda
* Anthony Scopatz
* Anton Akhmerov
* Antony Lee
* Arvind
* bduick
* Ben Root
* Benedikt Daurer
* Benedikt J. Daurer
* Benjamin Berg
* Benjamin Congdon
* BHT
* Björn Dahlgren
* Bruno Zohreh
* BTWS
* buefox
* Cameron Davidson-Pilon
* Cameron Fackler
* Chen Karako
* Chris Holdgraf
* Christian Stade-Schuldt
* Christoph Deil
* Christoph Gohlke
* Christopher Holdgraf
* Cimarron Mittelsteadt
* CJ Carey
* Colin
* Conner R. Phillips
* DaCoEx
* Dan Hickstein
* Daniel C. Marcu
* Daniel Laidig
* danielballan
* Danny Hermes
* DaveL17
* David A
* David Kent
* David Stansby
* deeenes
* Devashish Deshpande
* Diego Mora Cespedes
* Dietrich Brunn
* dlmccaffrey
* Dmitry Shachnev
* Dora Fraeman
* DoriekeMG
* Drew J. Sonne
* Dylan Evans
* E. G. Patrick Bos
* Egor Panfilov
* Elliott Sales de Andrade
* Elvis Stansvik
* endolith
* Eric Dill
* Eric Firing
* Eric Larson
* Erin Pintozzi
* Eugene Yurtsev
* Fabian-Robert Stöter
* FedeMiorelli
* Federico Ariza
* Felix Yan
* fibersnet
* Florencia Noriega
* Florian Le Bourdais
* Francoise Provencher
* Frank Yu
* Gauravjeet
* Gaute Hope
* gcallah
* Geoffrey Spear
* gepcel
* goldstarwebs
* greg-roper
* Grillard
* Guillermo Breto
* Gustavo Goretkin
* Hakan Kucukdereli
* hannah
* Hans Moritz Günther
* Hassan Kibirige
* Hastings Greer
* Heath Henley
* Heiko Oberdiek
* Henning Pohl
* Herbert Kruitbosch
* herilalaina
* Herilalaina Rakotoarison
* Ian Thomas
* Ilia Kurenkov
* Ilya Flyamer
* ImSoErgodic
* Isa Hassen
* Isaac Schwabacher
* Isaac Slavitt
* J. Goutin
* Jaap Versteegh
* Jacob McDonald
* jacob-on-github
* Jae-Joon Lee
* James A. Bednar
* Jan Schlüter
* Jan Schulz
* Jarrod Millman
* Jason King
* Jason Zheng
* Jeffrey Hokanson @ Loki
* Jens Hedegaard Nielsen
* jli
* Johannes Wienke
* John Vandenberg
* JojoBoulix
* jonchar
* Joseph Fox-Rabinovitz
* Joseph Jon Booker
* Jouni K. Seppänen
* Juan Nunez-Iglesias
* juan.gonzalez
* Julia Sprenger
* Julian Mehne
* Julian V. Modesto
* Julien L
* Julien Lhermitte
* Julien Schueller
* Jun Tan
* Kacper Kowalik (Xarthisius)
* kalagau
* Kanchana Ranasinghe
* Kanwar245
* Keerysanth Sribaskaran
* Kenneth Ma
* Kevin Keating
* khyox
* Kjartan Myrdal
* Klara Gerlei
* klaus
* klonuo
* Kristen M. Thyng
* kshramt
* Kyle Bridgemohansingh
* Kyler Brown
* Laptop11_ASPP2016
* lboogaard
* Leo Singer
* Levi Kilcher
* lspvic
* Luis Pedro Coelho
* lzkelley
* Maarten Baert
* Magnus Nord
* mamrehn
* Manuel Jung
* Massimo Santini
* Matt Hancock
* Matthew Brett
* Matthew Newville
* Matthias Bussonnier
* Matthias Lüthi
* Maximilian Albert
* Maximilian Maahn
* Mher Kazandjian
* Michael Droettboom
* Michiel de Hoon
* Mike Henninger
* Mike Jarvis
* MinRK
* mitch
* mlub
* mobando
* muahah
* myyc
* Naoya Kanai
* Nathan Goldbaum
* Nathan Musoke
* nbrunett
* Nelle Varoquaux
* nepix32
* Nicolas P. Rougier
* Nicolas Tessore
* Nikita Kniazev
* Nils Werner
* Ninad Bhat
* OceanWolf
* Orso Meneghini
* Pankaj Pandey
* patniharshit
* Paul Ganssle
* Paul Hobson
* Paul Ivanov
* Paul Kirow
* Paul Romano
* Pavol Juhas
* Pete Huang
* Pete Peterson
* Peter Iannucci
* Peter Mortensen
* Peter Würtz
* Petr Danecek
* Phil Elson
* Phil Ruffwind
* Pierre de Buyl
* productivememberofsociety666
* Przemysław Dąbek
* Qingpeng "Q.P." Zhang
* RAKOTOARISON Herilalaina
* Ramiro Gómez
* Randy Olson
* rebot
* Rishikesh
* rishikksh20
* Robin Dunn
* Robin Wilson
* Ronald Hartley-Davies
* Rui Lopes
* Ryan May
* RyanPan
* Salganos
* Salil Vanvari
* Samson
* Samuel St-Jean
* Sander
* scls19fr
* Scott Howard
* scott-vsi
* Sebastian Raschka
* Sebastián Vanrell
* Seraphim Alvanides
* serv-inc
* shaunwbell
* Simon Gibbons
* sindunuragarp
* Stefan Pfenninger
* Stephan Erb
* Sterling Smith
* Steven Silvester
* Steven Tilley
* Tadeo Corradi
* Terrence J. Katzenbaer
* Terrence Katzenbaer
* The Gitter Badger
* Thomas A Caswell
* Thomas Hisch
* Thomas Robitaille
* Thomas Spura
* Thorsten Liebig
* Tian Xia
* Till Stensitzki
* tmdavison
* Tobias Froehlich
* tomoemon
* Trish Gillett-Kawamoto
* Truong Pham
* Tuan
* Tuan333
* u55
* ultra-andy
* Valentin Schmidt
* Vedant Nanda
* Victor Zabalza
* Vidur Satija
* vraelvrangr
* Víctor Zabalza
* Warren Weckesser
* Wieland Hoffmann
* Will Silva
* William Granados
* Xufeng Wang
* yinleon
* Zbigniew Jędrzejewski-Szmek
* Zohreh

GitHub issues and pull requests:

Pull Requests (1003):

* :ghpull:`8594`: Missing return in _num_to_string()
* :ghpull:`8584`: Add pandas to python 3.6 build
* :ghpull:`8583`: Fix pandas datetime test on pandas 0.20
* :ghpull:`8566`: adding keyword plotting
* :ghpull:`8567`: Minor pytest parametrization
* :ghpull:`8554`: added basic_units download link to units examples
* :ghpull:`8545`: Add tutorials
* :ghpull:`8176`: Custom error message for draw_path. issues : #8131 (bad error message from pyplot.plot)
* :ghpull:`8185`: Implement blocking Qt event loop.
* :ghpull:`8346`: Use some more pytest plugins: warnings & rerunfailures
* :ghpull:`8536`: Update doc build.
* :ghpull:`8544`: updating developer docs
* :ghpull:`8548`: fixing scatter doc
* :ghpull:`8546`: nested pie example
* :ghpull:`8539`: Fix rectangular patches to be properly transformed on polar axes
* :ghpull:`8525`: Sphinx Gallery API pages + deprecating old examples folder
* :ghpull:`8538`: Update doc/thirdpartypackages/index.rst
* :ghpull:`8535`: Remove use of (deprecated) is_string_like in mplot3d.
* :ghpull:`8526`: Clarify docs for rcdefaults and friends.
* :ghpull:`8513`: Fix autoscaling with twinx and vspans: consider axis with one pair of finite limits ONLY
* :ghpull:`8523`: Update conda patch for AppVeyor build.
* :ghpull:`8522`: adding backreferences_dir param
* :ghpull:`8491`: Remove codecov coverage targets.
* :ghpull:`8518`: Discourage omitting backend in matplotlibrc
* :ghpull:`8486`: changed inherited Axes calls to super
* :ghpull:`8511`: Update front page so there's only one gallery
* :ghpull:`8510`: MNT: update GH issue template [ci skip]
* :ghpull:`8478`: Fixed Error: local variable 'xdata' referenced before assignment" in legend_handler.py
* :ghpull:`8502`: Update PR template to encourage PRs off not master.
* :ghpull:`8495`: Fix incorrect text line spacing.
* :ghpull:`8472`: migrate examples to sphinx-gallery
* :ghpull:`8488`: Build docs with oldest numpy on 2.7.
* :ghpull:`8377`: Clean up unit examples
* :ghpull:`8011`: Deprecate is_string_like, is_sequence_of_strings
* :ghpull:`7990`: Added a workaround for Jupyter notebooks
* :ghpull:`8324`: Update svg_tooltip.py
* :ghpull:`8380`: Make image_comparison more pytest-y
* :ghpull:`8485`: FIX markevery only accepts builtin integers, not numpy integers
* :ghpull:`8489`: Fix markup in plt.subplots docstring.
* :ghpull:`8490`: Clarify that Path.contains_x implicitly closes the Path.
* :ghpull:`8492`: Remove useless, confusing check in hist().
* :ghpull:`7931`: The font with the same weight name as the user specified weight name …
* :ghpull:`8256`: [DOC] Clean up bar_demo2
* :ghpull:`8455`: Added axes inversion to cla()
* :ghpull:`8474`: Check for non-finite axis limits placed on converted_limit
* :ghpull:`8482`: Modified PR Template
* :ghpull:`7572`: Overhaul external process calls
* :ghpull:`8394`: Unify WM_CLASS across backends
* :ghpull:`8447`: Let imshow handle float128 data.
* :ghpull:`8476`: Pull Request template
* :ghpull:`8450`: Don't bother disconnecting signals in TimerQt.__del__.
* :ghpull:`8468`: Clarify that Image.set_data doesn't update normalization.
* :ghpull:`8403`: New Feature - PolygonSelector Widget
* :ghpull:`8157`: add which kwarg to autofmt_xdate
* :ghpull:`8022`: Fixed Issue #7460: Raised an error if argument to xlim is invalid
* :ghpull:`8336`: Merged streamline examples
* :ghpull:`8399`: Fix % formatting and Transform equality.
* :ghpull:`8319`: FancyArrowPatch docstring overhaul
* :ghpull:`8452`: Revert #5392
* :ghpull:`8344`: Add simple ax.arrow test
* :ghpull:`8462`: Add container module to API docs
* :ghpull:`8456`: Migration to sphinx-gallery
* :ghpull:`8454`: Finish deprecating idle_event; style cleanups to backend_bases
* :ghpull:`8326`: Orthographic projection for mplot3d
* :ghpull:`8453`: Manually collect lines on checkbox example
* :ghpull:`8446`: Download the depsy.org badge when building the html documentation
* :ghpull:`8435`: Improve hist2d docstring by inlining properties.
* :ghpull:`8376`: Remove exceltools and gtktools from docs
* :ghpull:`8322`: Use scalars below a certain exponent in labes of log-scales axis
* :ghpull:`8374`: DOC update build dependencies
* :ghpull:`8339`: Give wide code blocks a scrollbar on website
* :ghpull:`8253`: Handle floating point round-off error when converting to pixels for h264 animations
* :ghpull:`8156`: DOC: Add missing cmaps to perception doc (fix for #8073)
* :ghpull:`8373`: [DOC] Updated the documentation
* :ghpull:`8391`: DOC: Update MEP 28
* :ghpull:`8340`: Refactor code duplication in ``matplotlib.markers``
* :ghpull:`8396`: DOC: Show off FuncFormatter as a decorator
* :ghpull:`8383`: Merge v2.0.x into master
* :ghpull:`8372`: MNT: cleanup whitespace around @_preprocess decorator
* :ghpull:`6310`: Make checkbuttons with all plotted lines with correct visibility automatically
* :ghpull:`7786`: Don't reshape offsets into the correct shape.
* :ghpull:`8254`: Adding headers for examples/units for MEP12/sphinx-gallery compliance
* :ghpull:`8369`: Use cbook._reshape_2D in hist.
* :ghpull:`8371`: DOC: Clean up the pie docstring PR
* :ghpull:`8343`: Make ArrowStyle docstrings numpydoc compatible
* :ghpull:`8368`: Cleanup appveyor.yml.
* :ghpull:`8334`: Fix Appveyor build.
* :ghpull:`8367`: symlog + minor ticks = exception
* :ghpull:`8258`: DOC: Clean up equal-aspect example
* :ghpull:`8116`: Simplify _reshape_2D.
* :ghpull:`8240`: DOC refactored installation instruction
* :ghpull:`8363`: DOC: update link to mpl-probscale
* :ghpull:`8362`: Add adjustText to the list of third party packages
* :ghpull:`7691`: ENH: Optional 3d bar shading
* :ghpull:`8264`: Fix leaky ps
* :ghpull:`8338`: Renamed all 'mtrans' into more common 'mtransforms'
* :ghpull:`8331`: Don't index into __builtins__ (not supported by PyPy).
* :ghpull:`8311`: DOC api's transition to sphinx-gallery is now complete
* :ghpull:`8287`: FIX: add __setstate__ function
* :ghpull:`8281`: Fix testing with tests.py on Py3.6.
* :ghpull:`8149`: Fix check for DISPLAY on PyQt5.
* :ghpull:`7844`: Fix containment test with nonlinear transforms.
* :ghpull:`8306`: DOC added titles to the rest of the 3D plots
* :ghpull:`8328`: Use neutral pronoun in docs.
* :ghpull:`8295`: Removes OldScalarFormatter #7956
* :ghpull:`8310`: DOC shapes and collections is fully SG compatible
* :ghpull:`8304`: Remove executable bit from examples and headers.
* :ghpull:`8229`: MEP12 ganged example
* :ghpull:`8301`: STY: fix whitespace in the tests
* :ghpull:`8248`: Inkscape shell mode.
* :ghpull:`8298`: Fix sphinx required version
* :ghpull:`8276`: MAINT moved some maintenance and helper python scripts to tools/
* :ghpull:`8275`: DOC moved changelog to the documentation
* :ghpull:`8262`: TST: fail on missing baseline file
* :ghpull:`8244`: BUG Ignore invisible axes in computing tight_layout
* :ghpull:`8018`: Cleanup visual_tests and disable browser opening
* :ghpull:`8268`: DOC moved spines examples sphinx-gallery
* :ghpull:`8239`: changes in travis's build environment
* :ghpull:`8274`: Removed obsolete license.py file
* :ghpull:`8165`: FIX: Remove type checking for strings in '_validate_linestyle'
* :ghpull:`8261`: Set __name__ for list validators in rcsetup.
* :ghpull:`8217`: Add option to rotate labels in a pie chart (#2304)
* :ghpull:`8227`: Contouring 1x1 array (issue #8197)
* :ghpull:`8269`: Use sys.executable -msphinx instead of sphinx-build.
* :ghpull:`8252`: Memoize parse_fontconfig_pattern; speeds up test suite by ~1min.
* :ghpull:`8047`: Correct theta values when drawing a non-circular arc
* :ghpull:`8245`: DOC: sphinx-gallery histograms
* :ghpull:`8241`: Remove image with non-free color calibration profile
* :ghpull:`7878`: Update vlines example with axes wide lines.
* :ghpull:`8237`: Fix pep8 violation
* :ghpull:`8224`: Implement Path.intersects_bbox in C++ to speed up legend positioning.
* :ghpull:`8228`: MEP12 text alignment example
* :ghpull:`8179`: TST: Enable cache directories on AppVeyor.
* :ghpull:`8211`: Mep12 text labels and annotations
* :ghpull:`8234`: fix gitter badge
* :ghpull:`8233`: changes to MEP12/sphinx-gallery compliant
* :ghpull:`8196`: Issue #8141: Dash validator allowing None values in addition to floats
* :ghpull:`8154`: merge fill_demo and fill_demo_features
* :ghpull:`8213`: TST: skip fc-list related tests if not installed
* :ghpull:`8172`: [MRG+1] [DOC] Turn ginput dostring into a numpydocstring
* :ghpull:`8173`: [MRG+1] Simplify and clean multicolor_line example
* :ghpull:`8221`: Early check for dot binary (from graphviz) when building the doc (fixes #8207)
* :ghpull:`8215`: Mep12 showcase
* :ghpull:`8212`: Mep12 ticks and spines
* :ghpull:`8219`: [DOC] Plural of axis is axes
* :ghpull:`7744`: Added axis limit check for non-finite values
* :ghpull:`5691`: Update documentation of stem to mention StemContainer
* :ghpull:`8175`: Add autoclass entry for Artist API doc.
* :ghpull:`8158`: Fix layout of spectrum_demo.py
* :ghpull:`8190`: add gitter link in README
* :ghpull:`8007`: Clean up BoundaryNorm docstring
* :ghpull:`8178`: Addresses #8177, Readme badges
* :ghpull:`8166`: MAINT: mappingview check for Python 3.4
* :ghpull:`8171`: DOC: Fix small typos in 'eventplot' docstring
* :ghpull:`8167`: Fixes typos in Artist tutorial
* :ghpull:`8161`: Add a code block in 'installing' docs.
* :ghpull:`8150`: Deprecate Axes.axesPatch, Figure.figurePatch.
* :ghpull:`8148`: Remove support for -dbackend argv.
* :ghpull:`8137`: Regenerate the gitwash docs.
* :ghpull:`6977`: Handle dvi font names as ASCII bytestrings
* :ghpull:`8066`: Clean up and move text rotation example
* :ghpull:`8134`: Update Slider docs and type check slidermin and slidermax.
* :ghpull:`8139`: DOC: Fixed x, y, docstring in errorbar
* :ghpull:`8133`: Disable network tests on AppVeyor.
* :ghpull:`8065`: Clean up and move accented text example
* :ghpull:`8119`: Drop None from Container.get_children().
* :ghpull:`8115`: Add branch coverage; exclude _version.py from coverage.
* :ghpull:`7995`: Set sticky_edges correctly for negative height bar().
* :ghpull:`8118`: Deprecate matplotlib.tests.assert_str_equal.
* :ghpull:`7394`: Cleanup transforms.py.
* :ghpull:`8036`: Tweak coverage
* :ghpull:`8110`: Mrg2.0.x
* :ghpull:`8103`: Use XDG config path on FreeBSD
* :ghpull:`8026`: Pytest documentation + build tweaks
* :ghpull:`8101`: Named Matplotlib module in windows instructions
* :ghpull:`8099`: Update examples/README.txt.
* :ghpull:`8094`: Remove example of matrix of size (12, 12) and (64, 64)
* :ghpull:`8040`: ENH: Stricter validation of line style rcParams (and extended accepted types for ``grid.linestyle``)
* :ghpull:`8097`: use plt.gca instead of plt.axes for already exhisting implicit axes
* :ghpull:`8096`: Improve error message for image_comparison decorator.
* :ghpull:`8085`: Fix PYTHONHASHSEED setup on OS X.
* :ghpull:`8086`: DOC: add SOURCELINK_SUFFIX for compatibility with Sphinx 1.5
* :ghpull:`8063`: Update MovieWriter dpi default
* :ghpull:`8084`: Add link to scipython book
* :ghpull:`7871`: Use backports.functools_lru_cache instead of functools32
* :ghpull:`8070`: Switch to suppress option to True in setup.cfg.template.
* :ghpull:`4997`: The url of downloading historical prices of Yahoo Finance has changed
* :ghpull:`8043`: Fix pyplot.axis(ax) when ax is in other figure.
* :ghpull:`8055`: Undeprecate is_scalar_or_string.
* :ghpull:`8060`: Added tight_layout() to example.
* :ghpull:`7968`: Fix cohere-demo
* :ghpull:`8033`: Update inline comment in set_and_get.py
* :ghpull:`7985`: Catch specgram warnings during tests
* :ghpull:`7965`: ENH: Fixed PercentFormatter usage with latex
* :ghpull:`8014`: do not ignore "closed" parameter in Poly3DCollection
* :ghpull:`7933`: Cleanup: use ``is not`` instead of ``not ... is``, etc.
* :ghpull:`7981`: Clarify backports documentation
* :ghpull:`8020`: Allow choosing logit scale in qt figure options.
* :ghpull:`8003`: Coverage config
* :ghpull:`7974`: Switch testing to pytest completely
* :ghpull:`8001`: Switch to pytest-pep8.
* :ghpull:`7993`: MAINT: Updated tick and category test formatting
* :ghpull:`8002`: Remove pytest_pycollect_makeitem.
* :ghpull:`7925`: Fix a number of Deprecated/Invalid escape sequences
* :ghpull:`7999`: More cbook deprecations.
* :ghpull:`7973`: Convert test decorators to pytest fixtures
* :ghpull:`7996`: Simplify implementation of is_numlike & is_string_like.
* :ghpull:`7998`: Display relative image paths when tests fail.
* :ghpull:`7997`: Default cmap is not jet anymore...
* :ghpull:`7809`: Fix for marker verts bug
* :ghpull:`7987`: Add vega deprecations to tests on master
* :ghpull:`7625`: Legend autopositioning with "spiraling" lines.
* :ghpull:`7983`: Remove assert_true calls from new PRs.
* :ghpull:`7980`: Coding Guide Edits
* :ghpull:`7959`: Allow zero sized ticks
* :ghpull:`7767`: Don't check ``iterable()`` before ``len()``.
* :ghpull:`7913`: Clean up quiver docstring + add simple quiver example
* :ghpull:`7023`: Add ``clf`` kwarg to plt.figure()
* :ghpull:`7857`: Fix/hide some deprecations
* :ghpull:`7961`: Compute glyph widths similarly in Type 42 as in Type 3
* :ghpull:`7972`: MAINT cleaning up of gallery examples.
* :ghpull:`7952`: MEP12 of showcase's examples + other folders.
* :ghpull:`7904`: twinx / twiny inherit autoscale behavior for shared axis
* :ghpull:`7935`: Finish removing nose
* :ghpull:`7859`: Fix typo in Axes3D.set_autoscalez_on.
* :ghpull:`7947`: MAINT testing.nose -> testing._nose to make it explicitely private
* :ghpull:`7960`: Don't try to build for py34 on appveyor
* :ghpull:`7949`: Remove ``sharex_foreign`` example, now useless.
* :ghpull:`7843`: MAINT: add ability to specify recursionlimit
* :ghpull:`7941`: Cleanup: remove unused variable/assignment/expression and debug comments
* :ghpull:`7944`: Improve hexbin performance
* :ghpull:`7938`: Fix typo in toolkits docs
* :ghpull:`7752`: bugfix for wx backend: release mouse on loss of focus and before trying to recapture
* :ghpull:`7914`: Fix unpickling of CallbackRegistry on Py2.
* :ghpull:`7929`: Remove a dead code (``font_manager.ttfdict_fnames``)
* :ghpull:`7932`: Convert remaining tests to pytest
* :ghpull:`7926`: Stop codecov from posting messages
* :ghpull:`7892`: Configure AppVeyor to fail fast
* :ghpull:`7934`: Run animation smoketest in a temporary directory.
* :ghpull:`7872`: Convert font/text tests to pytest
* :ghpull:`7915`: Convert sphinxext tests to pytest.
* :ghpull:`7898`: MAINT moved g-i-l* modules to pytest
* :ghpull:`7897`: MAINT moved all remaining "f" modules to pytest
* :ghpull:`7863`: Convert backend tests to use pytest
* :ghpull:`7907`: BUG: Add a newline separator in fc-list call
* :ghpull:`7920`: Convert preprocess tests to pytest
* :ghpull:`7887`: Convert mpl toolkits tests to pytest + minor cleanup
* :ghpull:`7918`: Convert test_s* files to pytest and flake8 them
* :ghpull:`7916`: Convert test_[ab]* files to pytest.
* :ghpull:`7923`: Fix leak of filedescriptor if fontsize cannot be set.
* :ghpull:`7900`: DOC MEP12: pie/polar and color examples + style sheets fix
* :ghpull:`7818`: Tripcolor.py: Remove documentation rendering error
* :ghpull:`7896`: Reject floatlike strings in mcolors.to_rgba.
* :ghpull:`7830`: MAINT moved _backports to cbook module
* :ghpull:`7883`: Convert mlab tests to pytest
* :ghpull:`7885`: MAINT moved all "d" modules to pytest.
* :ghpull:`7889`: Convert remaining test_t* files to pytest.
* :ghpull:`7748`: MAINT: Deterministic SVG and PDF tests
* :ghpull:`7884`: MAINT moved "c" modules to pytest
* :ghpull:`7890`: DOC Convert style sheet examples to MEP12
* :ghpull:`7888`: Transform test updates (pytest + cleanup)
* :ghpull:`7882`: MAINT pytest now exit on first failure on travis
* :ghpull:`7327`: DOC MEP12 - converted lines, bars and markers to SG/MEP12 compatible
* :ghpull:`7811`: Allow figure.legend to be called without arguments
* :ghpull:`7854`: !B [#7852] fix for _rrule maximum recursion depth exceeded on multiprocessing usage
* :ghpull:`7861`: Make radio and check buttons visible
* :ghpull:`7868`: MNT: reference the proper variable in bootstrapper
* :ghpull:`7817`: better input validation on ``fill_between``
* :ghpull:`7864`: Minor simplification of inset_locator_demo.
* :ghpull:`7865`: FIX Preserve title case when saving through GUI (issue #7824)
* :ghpull:`7850`: Allow AnchoredOffset to take a string-like location code
* :ghpull:`7845`: Fixed bug with default parameters NFFT and noverlap in specgram()
* :ghpull:`7800`: DOC: explain non-linear scales and imshow (closes #7661)
* :ghpull:`7639`: Enh color names
* :ghpull:`7829`: MAINT tests should not use relative imports
* :ghpull:`7828`: MAINT added early checks for dependencies for doc building
* :ghpull:`7424`: Numpy Doc Format
* :ghpull:`7821`: DOC: Changes to screenshots plots.
* :ghpull:`7644`: Allow scalar height for plt.bar
* :ghpull:`7838`: Merge v2.x
* :ghpull:`7823`: MAINT matplotlib -> Matplotlib
* :ghpull:`7833`: Deprecate unused verification code.
* :ghpull:`7827`: Cast stackplot input to float when required.
* :ghpull:`7834`: Remove deprecated get_example_data.
* :ghpull:`7826`: Remove invalid dimension checking in axes_rgb.
* :ghpull:`7831`: Function wrapper for examples/api/two_scales.py
* :ghpull:`7801`: Add short-circuit return to matplotlib.artist.setp if input is length 0
* :ghpull:`7740`: Beautified frontpage plots and two pylab examples
* :ghpull:`7730`: Fixed GraphicsContextBase linestyle getter
* :ghpull:`7747`: Update qhull to 2015.2
* :ghpull:`7645`: Clean up stock sample data.
* :ghpull:`7753`: Clarify the uses of whiskers float parameter.
* :ghpull:`7765`: TST: Clean up figure tests
* :ghpull:`7729`: For make raw_input compatible with python3
* :ghpull:`7783`: Raise exception if negative height or width is passed to axes()
* :ghpull:`7727`: DOC: Fix invalid nose argument in testing.rst
* :ghpull:`7731`: Check origin when saving image to PNG
* :ghpull:`7782`: Fix some more integer type inconsistencies in Freetype code
* :ghpull:`7781`: Fix integer types for font metrics in PyGlyph class
* :ghpull:`7791`: Use reliable int type for mesh size in draw_quad_mesh (#7788)
* :ghpull:`7796`: Only byte-swap 16-bit PNGs on little-endian (#7792)
* :ghpull:`7794`: Ignore images that doc build produces
* :ghpull:`7790`: Adjust markdown and text in ISSUE_TEMPLATE.md
* :ghpull:`7773`: Fix more invalid escapes sequences.
* :ghpull:`7769`: Remove redundant pep8 entry in .travis.yml.
* :ghpull:`7760`: DOC: Correct subplot() doc
* :ghpull:`7768`: Convert unicode index to long, not int, in get_char_index
* :ghpull:`7770`: BUG: improve integer step selection in MaxNLocator
* :ghpull:`7766`: Invalid escape sequences are deprecated in Py3.6.
* :ghpull:`7758`: fix axes barh default align option document
* :ghpull:`7749`: DOC: Sync keyboard shortcuts for fullscreen toggle
* :ghpull:`7757`: By default, don't include tests in binary distributions.
* :ghpull:`7762`: DOC: Fix finance depr docs to point to mpl_finance
* :ghpull:`7737`: Ensure that pyenv command is in a literal block
* :ghpull:`7732`: Add rcsetup_api.rst, fix typo for rcsetup.cycler
* :ghpull:`7726`: FIX: Clean up in the new quiverkey test; make new figs in scale tests
* :ghpull:`7620`: Add warning context
* :ghpull:`7719`: Add angle kwarg to quiverkey
* :ghpull:`7701`: DOC: Add bug report reqs and template to contributing guide
* :ghpull:`7723`: Use mplDeprecation class for all deprecations.
* :ghpull:`7676`: Makes eventplot legend work
* :ghpull:`7714`: TST: switch from 3.6-dev to 3.6
* :ghpull:`7713`: Declare Python 3.6 support via classifier in setup.py
* :ghpull:`7693`: Change majority of redirected links in docs
* :ghpull:`7705`: Fixes tzname return type
* :ghpull:`7703`: BF: Convert namespace path to list
* :ghpull:`7702`: DOC: Add link to bokeh/colorcet in colormaps.rst
* :ghpull:`7700`: DOC: Add gitter to home page
* :ghpull:`7692`: Corrected default values of xextent in specgram(). Fixes Bug #7666.
* :ghpull:`7698`: Update INSTALL for Python 3.6
* :ghpull:`7694`: Fix a few broken links in docs
* :ghpull:`7349`: Add support for png_text metadata, allow to customize metadata for other backends.
* :ghpull:`7670`: Decode error messages from image converters.
* :ghpull:`7677`: Make new default style examples consistent
* :ghpull:`7674`: Serialize comparison of multiple baseline images.
* :ghpull:`7665`: FIX: Fix super call for Python 2.7
* :ghpull:`7668`: Save SVG test directly to file instead of its name.
* :ghpull:`7549`: Cleanup: sorted, dict iteration, array.{ndim,size}, ...
* :ghpull:`7667`: FIX: Fix missing package
* :ghpull:`7651`: BUG,ENH: make deprecated decorator work (and more flexibly)
* :ghpull:`7658`: Avoid comparing numpy array to strings in two places
* :ghpull:`7657`: Fix warning when setting markeredgecolor to a numpy array
* :ghpull:`7659`: DOC: Original documentation was misleading
* :ghpull:`6780`: Call _transform_vmin_vmax during SymLogNorm.__init__
* :ghpull:`7646`: Improve deprecation documentation. Closes #7643
* :ghpull:`7604`: Warn if different axis projection requested
* :ghpull:`7568`: Deprecate unused functions in cbook.
* :ghpull:`6428`: Give a better error message on missing PostScript fonts
* :ghpull:`7585`: Fix a bug in TextBox where shortcut keys were not being reenabled
* :ghpull:`7628`: picker may not be callable.
* :ghpull:`7464`: ENH: _StringFuncParser to get numerical functions callables from strings
* :ghpull:`7622`: Mrg animation merge
* :ghpull:`7618`: DOC: fixed typo in mlab.py
* :ghpull:`7596`: Delay fc-list warning by 5s.
* :ghpull:`7607`: TST: regenerate patheffect2
* :ghpull:`7608`: Don't call np.min on generator.
* :ghpull:`7570`: Correctly skip colors for nan points given to scatter
* :ghpull:`7605`: Make bars stick to explicitly-specified edges.
* :ghpull:`6597`: Reproducible PS/PDF output (master)
* :ghpull:`7546`: Deprecate update_datalim_numerix&update_from_data.
* :ghpull:`7574`: Docs edits
* :ghpull:`7538`: Don't work out packages to install if user requests information from setup.p
* :ghpull:`7577`: Spelling fix: corosponding -> corresponding
* :ghpull:`7536`: Rectangle patch angle attribute and patch __str__ improvements
* :ghpull:`7547`: Additional cleanups
* :ghpull:`7544`: Cleanups
* :ghpull:`7548`: Clarify to_rgba docstring.
* :ghpull:`7476`: Sticky margins
* :ghpull:`7552`: Correctly extend a lognormed colorbar
* :ghpull:`7499`: Improve the the marker table in markers_api documentation
* :ghpull:`7468`: TST: Enable pytest-xdist
* :ghpull:`7530`: MAINT: TkAgg default backend depends on tkinter
* :ghpull:`7531`: double tolerance for test_png.py/pngsuite on Windows
* :ghpull:`7533`: FIX chinese character are hard to deal with in latex
* :ghpull:`7525`: Avoid division by zero if headlength=0 for quiver
* :ghpull:`7522`: Check at least one argument is provided for plt.table
* :ghpull:`7520`: Fix table.py bug
* :ghpull:`7397`: Numpydoc for backends
* :ghpull:`7513`: Doc: Typo in gridspec example subtitle
* :ghpull:`7494`: Remove some numpy 1.6 workarounds
* :ghpull:`7500`: Set hexbin default linecolor to 'face'
* :ghpull:`7498`: Fix double running of explicitly chosen tests.
* :ghpull:`7475`: Remove deprecated "shading" option to pcolor.
* :ghpull:`7436`: DOC: Fixed Unicode error in gallery template cache
* :ghpull:`7496`: Commit to fix a broken link
* :ghpull:`6062`: Add maximum streamline length property.
* :ghpull:`7470`: Clarify cross correlation documentation #1835
* :ghpull:`7481`: Minor cleanup of hist().
* :ghpull:`7474`: FIX/API: regenerate test figure due to hatch changes
* :ghpull:`7469`: TST: Added codecov
* :ghpull:`7467`: TST: Fixed part of a test that got displaced in all the changes somehow
* :ghpull:`7447`: Showcase example: (kind of mandatory) Mandelbrot set
* :ghpull:`7463`: Added additional coverage excludes
* :ghpull:`7449`: Clarify documentation of pyplot.draw
* :ghpull:`7454`: Avoid temporaries when preparing step plots.
* :ghpull:`7455`: Update two_scales.py example.
* :ghpull:`7456`: Add pytest's .cache to .gitignore.
* :ghpull:`7453`: TST: Fixed ``test_log_margins`` test
* :ghpull:`7144`: Cleanup scales
* :ghpull:`7442`: Added spacer to Tk toolbar
* :ghpull:`7444`: Enhance ``annotation_demoX`` examples
* :ghpull:`7439`: MEP12 API examples
* :ghpull:`7416`: MAINT deprecated 'spectral' in favor of 'nipy_spectral'
* :ghpull:`7435`: restore test that was inadvertently removed by 5901b38
* :ghpull:`7363`: Add appropriate error on color size mismatch in ``scatter``
* :ghpull:`7433`: FIX: search for tkinter first in builtins
* :ghpull:`7362`: Added ``-j`` shortcut for ``--processes=``
* :ghpull:`7408`: Handle nan/masked values Axes.vlines and hlines
* :ghpull:`7409`: FIX: MPL should not use new tool manager unless explicited asked for.  Closes #7404
* :ghpull:`7389`: DOC Convert axes docstrings to numpydoc: #7205
* :ghpull:`7417`: Merge from v2.x
* :ghpull:`7398`: Moved python files from doc/pyplots to examples folder
* :ghpull:`7291`: MEP 29: Markup text
* :ghpull:`6560`: Fillbetween
* :ghpull:`7399`: Clarify wspace/hspace in documentation/comments
* :ghpull:`7400`: fix ReST tag
* :ghpull:`7381`: Updating the readme
* :ghpull:`7384`: change hardcopy.docstring to docstring.hardcopy
* :ghpull:`7386`: ENH examples are now reproducible
* :ghpull:`7395`: Drop code that supports numpy pre-1.6.
* :ghpull:`7385`: remove unused random import
* :ghpull:`7236`: ENH Improving the contribution guidelines
* :ghpull:`7370`: Add example use of axes.spines.SIDE prop in matplotlibrc
* :ghpull:`7367`: Warn on invalid log axis limits, per issue #7299
* :ghpull:`7360`: Updated violin plot example as per suggestions in issue #7251
* :ghpull:`7357`: Added notes on how to use matplotlib in pyenv
* :ghpull:`7329`: DOC MEP12 - converted animation to SG/MEP12 compatible
* :ghpull:`7337`: FIX symlog scale now shows negative labels.
* :ghpull:`7354`: fix small error in poly_editor example
* :ghpull:`7310`: TST: Make proj3d tests into real tests
* :ghpull:`7331`: MEP12 improvments for statistics plots
* :ghpull:`7340`: DOC: Normalize symlink target
* :ghpull:`7328`: TST: Fixed rcparams ``test_Issue_1713`` test
* :ghpull:`7303`: Traceback to help fixing double-calls to mpl.use.
* :ghpull:`7346`: DOC: Fix annotation position (issue #7345)
* :ghpull:`5392`: BUG: arrowhead drawing code
* :ghpull:`7318`: Convert a few test files to Pytest
* :ghpull:`7323`: Fix #6448: set xmin/ymin even without non-zero bins in 'step' hist
* :ghpull:`7326`: Enable coverage sending on pytest build
* :ghpull:`7321`: Remove bundled virtualenv module
* :ghpull:`7290`: Remove deprecated stuff schedule for removal.
* :ghpull:`7324`: DOC: Boxplot color demo update
* :ghpull:`6476`: Add a common example to compare style sheets
* :ghpull:`7309`: MEP28: fix rst syntax for code blocks
* :ghpull:`7250`: Adds docstrings to demo_curvelinear_grid.py and demo_curvelinear_grid…
* :ghpull:`4128`: Code removal for post 1.5/2.1
* :ghpull:`7308`: Fix travis nightly build
* :ghpull:`7282`: Draft version of MEP28: Simplification of boxplots
* :ghpull:`7304`: DOC: Remove duplicate documentation from last merge.
* :ghpull:`7249`: add docstring to example: axisartist/demo_floating_axes.py
* :ghpull:`7296`: MAINT removing docstring dedent_interpd when possible
* :ghpull:`7298`: Changed Examples for Pep8 Compliance
* :ghpull:`7295`: MAINT finance module is deprecated
* :ghpull:`7214`: FIX: Only render single patch for scatter
* :ghpull:`7297`: MAINT docstring appending doesn't mess with rendering anymore.
* :ghpull:`6907`: Filled + and x markers
* :ghpull:`7288`: Style typos fixes
* :ghpull:`7277`: MEP12 - added sphinx-gallery docstrings
* :ghpull:`7286`: DOC: Fix for #7283 by adding a trailing underscore to misrendered URLs
* :ghpull:`7285`: added some fixes to the documentation of the functions
* :ghpull:`6690`: Tidying up and tweaking mplot3d examples [MEP12]
* :ghpull:`7273`: Fix image watermark example where image was hidden by axes (#7265)
* :ghpull:`7276`: FIX: don't compute flier positions if not showing
* :ghpull:`7267`: DOC: changed documentation for axvspan to numpydoc format
* :ghpull:`7268`: DOC Numpydoc documentation for def fill()
* :ghpull:`7272`: Don't use __builtins__ (an impl. detail) in pylab.
* :ghpull:`7241`: Categorical support for NumPy string arrays.
* :ghpull:`7232`: DOC improved subplots' docstring
* :ghpull:`7256`: CI: skip failing test on appveyor
* :ghpull:`7255`: CI: pin to qt4
* :ghpull:`7229`: DOC: instructions on installing matplotlib for dev
* :ghpull:`7252`: ENH: improve PySide2 loading
* :ghpull:`7245`: TST: Always produce image comparison test result images
* :ghpull:`6677`: Remove a copy in pcolormesh.
* :ghpull:`6814`: Customize violin plot demo, see #6723
* :ghpull:`7067`: DOC: OO interface in api and other examples
* :ghpull:`6790`: BUG: fix C90 warning -> error in new tkagg code
* :ghpull:`7242`: Add mplcursors to third-party packages.
* :ghpull:`7222`: Catch IO errors when building font cache
* :ghpull:`7220`: Fix innocent typo in comments
* :ghpull:`7192`: DOC: switch pylab example ``mri_with_eeg.py`` to OO interface + cosmetick fixes
* :ghpull:`6583`: Fix default parameters of FancyArrow
* :ghpull:`7195`: remove check under linux for ~/.matplotlib
* :ghpull:`6753`: Don't warn when legend() finds no labels.
* :ghpull:`7178`: Boxplot zorder kwarg
* :ghpull:`6327`: Fix captions for plot directive in latex target
* :ghpull:`7188`: Remove hard-coded streamplot zorder kwarg
* :ghpull:`7170`: DOC updated hexbin documentation to numpydoc format.
* :ghpull:`7031`: DOC Replaced documentation with numpydoc for semilogx
* :ghpull:`7029`: [WIP] DOC Updated documentation of arrow function to numpy docs format.
* :ghpull:`7167`: Less stringent normalization test for float128.
* :ghpull:`7169`: Remove unused variable.
* :ghpull:`7066`: DOC: switch to O-O interface in basic examples
* :ghpull:`7084`: [DOC] Tick locators & formatters examples
* :ghpull:`7152`: Showcase example: Bézier curves & SVG
* :ghpull:`7019`: Check for fontproperties in figure.suptitle.
* :ghpull:`7145`: Add ``style`` to api doc; fix capitalization.
* :ghpull:`7097`: ``image_comparison`` decorator refactor
* :ghpull:`7096`: DOC refer to plot in the scatter plot doc
* :ghpull:`7140`: FIX added matplotlib.testing.nose.plugins to setupext.py
* :ghpull:`5112`: OffsetImage: use dpi_cor in get_extent
* :ghpull:`7136`: DOC: minor fix  in development_workflow.rst
* :ghpull:`7137`: DOC: improve engineering formatter example
* :ghpull:`7131`: Fix branch name in "Deleting a branch on GitHub\_" section
* :ghpull:`6521`: Issue #6429 fix
* :ghpull:`7111`: [DOC] Fix example following comments in  issue #6865
* :ghpull:`7118`: PR # 7038 rebased (DOC specgram() documentation now in numpy style)
* :ghpull:`7117`: PR #7030 rebased
* :ghpull:`6618`: Small improvements to legend's docstring.
* :ghpull:`7102`: Adding the artist data on mouse move event message
* :ghpull:`7110`: [DOC] Apply comments from issue #7017
* :ghpull:`7087`: [DOC] Example of user-defined linestyle (TikZ linestyle)
* :ghpull:`7108`: Typos in ticker.py
* :ghpull:`7035`: DOC Update semilogy docstring to numpy doc format
* :ghpull:`7033`: DOC Updated plot_date to NumPy/SciPy style
* :ghpull:`7032`: DOC: Updating docstring to numpy doc format for errorbar
* :ghpull:`7094`: TST: Restore broken ``test_use14corefonts``
* :ghpull:`6995`: Turn off minor grids when interactively turning off major grids.
* :ghpull:`7072`: [DOC] New figure for the gallery (showcase section)
* :ghpull:`7077`: label_outer() should remove inner minor ticks too.
* :ghpull:`7037`: DOC change axhspan to numpydoc format
* :ghpull:`7047`: DOC - SpanSelector widget documentation
* :ghpull:`7049`: Documentated dependencies to the doc and remove unecessary dependencies.
* :ghpull:`7063`: Tweek tol for test_hist_steplog to fix tests on appveyor
* :ghpull:`7055`: FIX: testings.nose was not installed
* :ghpull:`7058`: Minor animation fixes
* :ghpull:`7057`: FIX: Removed financial demos that stalled because of yahoo requests
* :ghpull:`7052`: Uncaught exns are fatal for PyQt5, so catch them.
* :ghpull:`7048`: FIX: remove unused variable
* :ghpull:`7042`: FIX: ticks filtered by Axis, not in Tick.draw
* :ghpull:`7026`: Merge 2.x to master
* :ghpull:`6988`: Text box widget, take over of PR5375
* :ghpull:`6957`: DOC: clearing out some instances of using pylab in the docs
* :ghpull:`7012`: Don't blacklist test_usetex using pytest
* :ghpull:`7011`: TST: Fixed ``skip_if_command_unavailable`` decorator problem
* :ghpull:`6918`: enable previously leftout test_usetex
* :ghpull:`7006`: FIX: sphinx 1.4.0 details
* :ghpull:`6900`: Enh: break website screenshot banner into 4 pieces and introduce a responsive layout
* :ghpull:`6997`: FIX: slow plots of pandas objects (Second try)
* :ghpull:`6792`: PGF Backend: Support interpolation='none'
* :ghpull:`6983`: Catch invalid interactive switch to log scale.
* :ghpull:`6491`: Don't warn in Collections.contains if picker is not numlike.
* :ghpull:`6978`: Add link to O'Reilly video course covering matplotlib
* :ghpull:`6930`: BUG: PcolorImage handles non-contiguous arrays, provides data readout
* :ghpull:`6889`: support for updating axis ticks for categorical data
* :ghpull:`6974`: Fixed wrong expression
* :ghpull:`6730`: Add Py.test testing framework support
* :ghpull:`6904`: Use edgecolor rather than linewidth to control edge display.
* :ghpull:`6919`: Rework MaxNLocator, eliminating infinite loop; closes #6849
* :ghpull:`6955`: Add parameter checks to DayLocator initiator
* :ghpull:`5161`: Proposed change to default log scale tick formatting
* :ghpull:`6875`: Add keymap (default: G) to toggle minor grid.
* :ghpull:`6920`: Prepare for cross-framework test suite
* :ghpull:`6944`: Restore cbook.report_memory, which was deleted in d063dee.
* :ghpull:`6961`: remove extra "a"
* :ghpull:`6947`: Changed error message. Issue #6933
* :ghpull:`6923`: Make sure nose is only imported when needed
* :ghpull:`6851`: Do not restrict coverage to ``matplotlib`` module only
* :ghpull:`6938`: Image interpolation selector in Qt figure options.
* :ghpull:`6787`: Python3.5 dictview support
* :ghpull:`6407`: adding default toggled state for toggle tools
* :ghpull:`6898`: Fix read mode when loading cached AFM fonts
* :ghpull:`6892`: Don't force anncoords to fig coords upon dragging.
* :ghpull:`6895`: Prevent forced alpha in figureoptions.
* :ghpull:`6877`: Fix Path deepcopy signature
* :ghpull:`6822`: Use travis native cache
* :ghpull:`6821`: Break reference cycle Line2D <-> Line2D._lineFunc.
* :ghpull:`6879`: Delete font cache in one of the configurations
* :ghpull:`6832`: Fix for ylabel title in example tex_unicode_demo.py
* :ghpull:`6848`: ``test_tinypages``: pytest compatible module level setup
* :ghpull:`6881`: add doi to bibtex entry for Hunter (2007)
* :ghpull:`6842`: Clarify Axes.hexbin *extent* docstring
* :ghpull:`6861`: Update ggplot URLs
* :ghpull:`6878`: DOC: use venv instead of virtualenv on python 3
* :ghpull:`6837`: Fix Normalize(<signed integer array>).
* :ghpull:`6874`: Update bachelors_degree_by_gender example.
* :ghpull:`6867`: Mark ``make_all_2d_testfuncs`` as not a test
* :ghpull:`6854`: Fix for PyQt5.7 support.
* :ghpull:`6862`: Change default doc image format to png and pdf
* :ghpull:`6819`: Add mpl_toolkits to coveragerc.
* :ghpull:`6840`: Fixed broken ``test_pickle.test_complete`` test
* :ghpull:`6841`: DOC: Switch to OO code style & ensure fixed y-range in ``psd_demo3``
* :ghpull:`6843`: DOC: Fix ``psd_demo_complex`` similarly to ``psd_demo3``
* :ghpull:`6829`: Tick label rotation via ``set_tick_params``
* :ghpull:`6799`: Allow creating annotation arrows w/ default props.
* :ghpull:`6262`: Properly handle UTC conversion in date2num.
* :ghpull:`6777`: Raise lock timeout as actual exception
* :ghpull:`6817`: DOC: Fix a few typos and formulations
* :ghpull:`6826`: Clarify doc for "norm" kwarg to ``imshow``.
* :ghpull:`6807`: Deprecate ``{get,set}_cursorprops``.
* :ghpull:`6811`: Add xkcd font as one of the options
* :ghpull:`6815`: Rename tests in ``test_mlab.py``
* :ghpull:`6808`: Don't forget to disconnect callbacks for dragging.
* :ghpull:`6803`: better freetype version checking
* :ghpull:`6778`: Added contribute information to readme
* :ghpull:`6786`: 2.0 Examples fixes. See #6762
* :ghpull:`6774`: Appveyor: use newer conda packages and only run all tests on one platform
* :ghpull:`6779`: Fix tutorial pyplot scales (issue #6775)
* :ghpull:`6768`: Takeover #6535
* :ghpull:`6763`: Invalidate test cache on gs/inkscape version
* :ghpull:`6765`: Get more rcParams for 3d
* :ghpull:`6764`: Support returning polylines from to_polygons
* :ghpull:`6760`: DOC: clean up of demo_annotation_box.py
* :ghpull:`6735`: Added missing side tick rcParams
* :ghpull:`6761`: Fixed warnings catching and counting with ``warnings.catch_warnings``
* :ghpull:`5349`: Add a Gitter chat badge to README.rst
* :ghpull:`6755`: PEP: fix minor formatting issues
* :ghpull:`6699`: Warn if MPLBACKEND is invalid.
* :ghpull:`6754`: Fixed error handling in ``ImageComparisonTest.setup_class``
* :ghpull:`6734`: register IPython's eventloop integration in plt.install_repl_displayhook
* :ghpull:`6745`: DOC: typo in broken_axis pylab example
* :ghpull:`6747`: Also output the actual error on svg backend tests using subprocess
* :ghpull:`6744`: Add workaround for failures due to newer miktex
* :ghpull:`6741`: Missing ``cleanup`` decorator in ``test_subplots.test_exceptions``
* :ghpull:`6736`: doc: fix unescaped backslash
* :ghpull:`6733`: Mergev2.x to master
* :ghpull:`6729`: Fix crash if byte-compiled level 2
* :ghpull:`6575`: setup.py: Recommend installation command for pkgs
* :ghpull:`6645`: Fix containment and subslice optim. for steps.
* :ghpull:`6619`: Hide "inner" {x,y}labels in label_outer too.
* :ghpull:`6639`: Simplify get_legend_handler method
* :ghpull:`6694`: Improve Line2D and MarkerStyle instantiation
* :ghpull:`6692`: Remove explicit children invalidation in update_position method
* :ghpull:`6703`: DOC: explain behavior of notches beyond quartiles
* :ghpull:`6707`: Call ``gc.collect`` after each test only if the user asks for it
* :ghpull:`6711`: Added support for ``mgs`` to Ghostscript dependecy checker
* :ghpull:`6700`: Don't convert vmin, vmax to floats.
* :ghpull:`6714`: fixed font_manager.is_opentype_cff_font()
* :ghpull:`6701`: Colours like 'XeYYYY' don't get recognised properly if X, Y's are numbers
* :ghpull:`6512`: Add computer modern font family
* :ghpull:`6383`: Qt editor alpha
* :ghpull:`6381`: Fix canonical name for "None" linestyle.
* :ghpull:`6689`: Str Categorical Axis Support
* :ghpull:`6686`: Merged _bool from axis into cbook._string_to_bool
* :ghpull:`6683`: New entry in ``.mailmap``
* :ghpull:`6520`: Appveyor overhaul
* :ghpull:`6697`: Fixed path caching bug in ``Path.unit_regular_star``
* :ghpull:`6688`: DOC: fix radial increase of size & OO style in polar_scatter_demo
* :ghpull:`6681`: Fix #6680 (minor typo in IdentityTransform docstring)
* :ghpull:`6676`: Fixed AppVeyor building script
* :ghpull:`6672`: Fix example of streamplot ``start_points`` option
* :ghpull:`6601`: BF: protect against locale in sphinext text
* :ghpull:`6662`: adding from_list to custom cmap tutorial
* :ghpull:`6666`: Guard against too-large figures
* :ghpull:`6659`: Fix image alpha
* :ghpull:`6642`: Fix rectangle selector release bug
* :ghpull:`6652`: Minor doc updates.
* :ghpull:`6653`: DOC: Incorrect rendering of dashes
* :ghpull:`6648`: adding a new color and editing an existing color in fivethirtyeight.mplstyle
* :ghpull:`6548`: Fix typo.
* :ghpull:`6628`: fix the swab bug to compile on solaris system
* :ghpull:`6622`: colors: ensure masked array data is an ndarray
* :ghpull:`6625`: DOC: Found a typo.
* :ghpull:`6614`: Fix docstring for PickEvent.
* :ghpull:`6554`: Update mpl_toolkits.gtktools.
* :ghpull:`6564`: Cleanup for drawstyles.
* :ghpull:`6577`: Fix mlab.rec_join.
* :ghpull:`6596`: Added a new example to create error boxes using a PatchCollection
* :ghpull:`2370`: Implement draw_markers in the cairo backend.
* :ghpull:`6599`: Drop conditional import of figureoptions.
* :ghpull:`6573`: Some general cleanups
* :ghpull:`6568`: Add OSX to travis tests
* :ghpull:`6600`: Typo: markeredgewith -> markeredgewidth
* :ghpull:`6526`: ttconv: Also replace carriage return with spaces.
* :ghpull:`6530`: Update make.py
* :ghpull:`6405`: ToolManager/Tools adding methods to set figure after initialization
* :ghpull:`6553`: Drop prettyplotlib from the list of toolkits.
* :ghpull:`6557`: Merge 2.x to master
* :ghpull:`5626`: New toolbar icons
* :ghpull:`6555`: Fix docstrings for ``warn_deprecated``.
* :ghpull:`6544`: Fix typo in margins handling.
* :ghpull:`6014`: Patch for issue #6009
* :ghpull:`6517`: Fix conversion of string grays with alpha.
* :ghpull:`6522`: DOC: made sure boxplot demos share y-axes
* :ghpull:`6529`: TST Remove plt.show() from test_axes.test_dash_offset
* :ghpull:`6519`: Fix FigureCanvasAgg.print_raw(...)
* :ghpull:`6481`: Default boxplot style rebase
* :ghpull:`6504`: Patch issue 6035 rebase
* :ghpull:`5593`: ENH: errorbar color cycle clean up
* :ghpull:`6497`: Line2D._path obeys drawstyle.
* :ghpull:`6487`: Added docstring to scatter_with_legend.py [MEP12]
* :ghpull:`6485`: Barchart demo example clean up [MEP 12]
* :ghpull:`6472`: Install all dependencies from pypi
* :ghpull:`6482`: Skip test broken with numpy 1.11
* :ghpull:`6475`: Do not turn on interactive mode on in example script
* :ghpull:`6442`: loading TCL / Tk symbols dynamically
* :ghpull:`6467`: ENH: add unified seaborn style sheet
* :ghpull:`6465`: updated boxplot figure
* :ghpull:`6462`: CI: Use Miniconda already installed on AppVeyor.
* :ghpull:`6456`: FIX: unbreak master after 2.x merge
* :ghpull:`6445`: Offset text colored by labelcolor param
* :ghpull:`6417`: Showraise gtk gtk3
* :ghpull:`6423`: TST: splitlines in rec2txt test
* :ghpull:`6427`: Output pdf dicts in deterministic order
* :ghpull:`6431`: Merge from v2.x
* :ghpull:`6433`: Make the frameworkpython script compatible with Python 3
* :ghpull:`6358`: Stackplot weighted_wiggle zero-area fix
* :ghpull:`6382`: New color conversion machinery.
* :ghpull:`6372`: DOC: add whats_new for qt configuration editor.
* :ghpull:`6415`: removing unused DialogLineprops from gtk3
* :ghpull:`6390`: Use xkcd: prefix to avoid color name clashes.
* :ghpull:`6397`: key events handler return value to True to stop propagation
* :ghpull:`6402`: more explicit message for missing image
* :ghpull:`5785`: Better choice of offset-text.
* :ghpull:`6302`: FigureCanvasQT key auto repeat
* :ghpull:`6334`: ENH: webagg: Handle ioloop shutdown correctly
* :ghpull:`5267`: AutoMinorLocator and and logarithmic axis
* :ghpull:`6386`: Minor improvements concerning #6353 and #6357
* :ghpull:`6388`: Remove wrongly commited test.txt
* :ghpull:`6379`: Install basemap from git trying to fix build issue with docs
* :ghpull:`6369`: Update demo_floating_axes.py with comments
* :ghpull:`6377`: Remove unused variable in GeoAxes class
* :ghpull:`6373`: Remove misspelled and unused variable in GeoAxes class
* :ghpull:`6376`: Update index.rst - add Windrose as third party tool
* :ghpull:`6371`: Set size of static figure to match widget on hidp displays
* :ghpull:`6370`: Restore webagg backend following the merge of widget nbagg backend
* :ghpull:`6366`: Sort default labels numerically in Qt editor.
* :ghpull:`6367`: Remove stray nonascii char from nbagg
* :ghpull:`5754`: IPython Widget
* :ghpull:`6146`: ticker.LinearLocator view_limits algorithm improvement closes #6142
* :ghpull:`6287`: ENH: add axisbelow option 'line', make it the default
* :ghpull:`6339`: Fix #6335: Queue boxes to update
* :ghpull:`6347`: Allow setting image clims in Qt options editor.
* :ghpull:`6354`: Update events handling documentation to work with Python 3.
* :ghpull:`6356`: Merge 2.x to master
* :ghpull:`6304`: Updating animation file writer to allow keywork arguments when using ``with`` construct
* :ghpull:`6328`: Add default scatter marker option to rcParams
* :ghpull:`6342`: Remove shebang lines from all examples. [MEP12]
* :ghpull:`6337`: Add a 'useMathText' param to method 'ticklabel_format'
* :ghpull:`6346`: Avoid duplicate cmap in image options.
* :ghpull:`6253`: MAINT: Updates to formatters in ``matplotlib.ticker``
* :ghpull:`6291`: Color cycle handling
* :ghpull:`6340`: BLD: make minimum cycler version 0.10.0
* :ghpull:`6322`: Typo fixes and wording modifications (minor)
* :ghpull:`6319`: Add PyUpSet as extension
* :ghpull:`6314`: Only render markers on a line when markersize > 0
* :ghpull:`6303`: DOC Clean up on about half the Mplot3d examples
* :ghpull:`6311`: Seaborn sheets
* :ghpull:`6300`: Remake of #6286
* :ghpull:`6297`: removed duplicate word in Choosing Colormaps documentation
* :ghpull:`6200`: Tick vertical alignment
* :ghpull:`6203`: Fix #5998: Support fallback font correctly
* :ghpull:`6198`: Make hatch linewidth an rcParam
* :ghpull:`6275`: Fix cycler validation
* :ghpull:`6283`: Use ``figure.stale`` instead of internal member in macosx
* :ghpull:`6247`: DOC: Clarify fillbetween_x example.
* :ghpull:`6251`: ENH: Added a ``PercentFormatter`` class to ``matplotlib.ticker``
* :ghpull:`6267`: MNT: trap inappropriate use of color kwarg in scatter; closes #6266
* :ghpull:`6249`: Adjust test tolerance to pass for me on OSX
* :ghpull:`6263`: TST: skip broken test
* :ghpull:`6260`: Bug fix and general touch ups for hist3d_demo example (#1702)
* :ghpull:`6239`: Clean warnings in examples
* :ghpull:`6170`: getter for ticks for colorbar
* :ghpull:`6246`: Merge v2.x into master
* :ghpull:`6238`: Fix sphinx 1.4.0 issues
* :ghpull:`6241`: Force Qt validator to use C locale.
* :ghpull:`6234`: Limit Sphinx to 1.3.6 for the time being
* :ghpull:`6178`: Use Agg for rendering in the Mac OSX backend
* :ghpull:`6232`: MNT: use stdlib tools in allow_rasterization
* :ghpull:`6211`: A method added to Colormap classes to reverse the colormap
* :ghpull:`6205`: Use io.BytesIO instead of io.StringIO in examples
* :ghpull:`6229`: Add a locator to AutoDateFormatters example code
* :ghpull:`6222`: ENH: Added ``file`` keyword to ``setp`` to redirect output
* :ghpull:`6217`: BUG: Made ``setp`` accept arbitrary iterables
* :ghpull:`6154`: Some small cleanups based on Quantified code
* :ghpull:`4446`: Label outer offset text
* :ghpull:`6218`: DOC: fix typo
* :ghpull:`6202`: Fix #6136: Don't hardcode default scatter size
* :ghpull:`6195`: Documentation bug #6180
* :ghpull:`6194`: Documentation bug fix: #5517
* :ghpull:`6011`: Fix issue #6003
* :ghpull:`6179`: Issue #6105: Adds targetfig parameter to the subplot2grid function
* :ghpull:`6185`: Fix to csv2rec bug for review
* :ghpull:`6192`: More precise choice of axes limits.
* :ghpull:`6176`: DOC: Updated docs for rc_context
* :ghpull:`5617`: Legend tuple handler improve
* :ghpull:`6188`: Merge 2x into master
* :ghpull:`6158`: Fix: pandas series of strings
* :ghpull:`6156`: Bug: Fixed regression of ``drawstyle=None``
* :ghpull:`5343`: Boxplot stats w/ equal quartiles
* :ghpull:`6132`: Don't check if in range if the caller passed norm
* :ghpull:`6091`: Fix for issue 5575 along with testing
* :ghpull:`6123`: docstring added
* :ghpull:`6145`: BUG: Allowing unknown drawstyles
* :ghpull:`6148`: Fix: Pandas indexing Error in collections
* :ghpull:`6140`: clarified color argument in scatter
* :ghpull:`6137`: Fixed outdated link to thirdpartypackages, and simplified the page
* :ghpull:`6095`: Bring back the module level 'backend'
* :ghpull:`6124`: Fix about dialog on Qt 5
* :ghpull:`6110`: Fixes matplotlib/matplotlib#1235
* :ghpull:`6122`: MNT: improve image array argument checking in to_rgba. Closes #2499.
* :ghpull:`6047`: bug fix related #5479
* :ghpull:`6119`: added comment on "usetex=False" to ainde debugging when latex not ava…
* :ghpull:`6073`: fixed bug 6028
* :ghpull:`6116`: CI: try explicitly including msvc_runtime
* :ghpull:`6100`: Update INSTALL
* :ghpull:`6099`: Fix #6069.  Handle image masks correctly
* :ghpull:`6079`: Fixed Issue 4346
* :ghpull:`6102`: Update installing_faq.rst
* :ghpull:`6101`: Update INSTALL
* :ghpull:`6074`: Fixes an error in the documentation, linestyle is dash_dot and should be dashdot
* :ghpull:`6068`: Text class: changed __str__ method and added __repr__ method
* :ghpull:`6018`: Added get_status() function to the CheckButtons widget
* :ghpull:`6013`: Mnt cleanup pylab setup
* :ghpull:`5984`: Suggestion for Rasterization to docs pgf-backend
* :ghpull:`5911`: Fix #5895: Properly clip MOVETO commands
* :ghpull:`6039`: DOC: added missing import to navigation_toolbar.rst
* :ghpull:`6036`: BUG: fix ListedColormap._resample, hence plt.get_cmap; closes #6025
* :ghpull:`6029`: TST: Always use / in URLs for visual results.
* :ghpull:`6022`: Make @cleanup *really* support generative tests.
* :ghpull:`6024`: Add Issue template with some guidelines
* :ghpull:`5718`: Rewrite of image infrastructure
* :ghpull:`3973`: WIP: BUG: Convert qualitative colormaps to ListedColormap
* :ghpull:`6005`: FIX: do not short-cut all white-space strings
* :ghpull:`5727`: Refresh pgf baseline images.
* :ghpull:`5975`: ENH: add kwarg normalization function to cbook
* :ghpull:`5931`: use ``locale.getpreferredencoding()`` to prevent OS X locale issues
* :ghpull:`5972`: add support for PySide2, #5971
* :ghpull:`5625`: DOC: add FAQ about np.datetime64
* :ghpull:`5131`: fix #4854: set default numpoints of legend entries to 1
* :ghpull:`5926`: Fix #5917. New dash patterns. Scale dashes by lw
* :ghpull:`5976`: Lock calls to latex in texmanager
* :ghpull:`5628`: Reset the available animation movie writer on rcParam change
* :ghpull:`5951`: tkagg: raise each new window; partially addresses #596
* :ghpull:`5958`: TST: add a test for tilde in tempfile for the PS backend
* :ghpull:`5957`: Win: add mgs as a name for ghostscript executable
* :ghpull:`5928`: fix for latex call on PS backend (Issue #5895)
* :ghpull:`5954`: Fix issues with getting tempdir when unknown uid
* :ghpull:`5922`: Fixes for Windows test failures on appveyor
* :ghpull:`5953`: Fix typos in Axes.boxplot and Axes.bxp docstrings
* :ghpull:`5947`: Fix #5944: Fix PNG writing from notebook backend
* :ghpull:`5936`: Merge 2x to master
* :ghpull:`5629`: WIP: more windows build and CI changes
* :ghpull:`5914`: Make barbs draw correctly (Fixes #5803)
* :ghpull:`5906`: Merge v2x to master
* :ghpull:`5809`: Support generative tests in @cleanup.
* :ghpull:`5910`: Fix reading/writing from urllib.request objects
* :ghpull:`5882`: mathtext: Fix comma behaviour at start of string
* :ghpull:`5880`: mathtext: Fix bugs in conversion of apostrophes to primes
* :ghpull:`5872`: Fix issue with Sphinx 1.3.4
* :ghpull:`5894`: Boxplot concept figure update
* :ghpull:`5870`: Docs / examples fixes.
* :ghpull:`5892`: Fix gridspec.Gridspec: check ratios for consistency with rows and columns
* :ghpull:`5901`: Fixes incorrect ipython sourcecode
* :ghpull:`5893`: Show significant digits by default in QLineEdit.
* :ghpull:`5881`: Allow build children to run
* :ghpull:`5886`: Revert "Build the docs with python 3.4 which should fix the Traitlets…
* :ghpull:`5877`: DOC: added blurb about external mpl-proscale package
* :ghpull:`5879`: Build the docs with python 3.4 which should fix the Traitlets/IPython…
* :ghpull:`5871`: Fix sized delimiters for regular-sized mathtext (#5863)
* :ghpull:`5852`: FIX: create _dashSeq and _dashOfset before use
* :ghpull:`5832`: Rewordings for normalizations docs.
* :ghpull:`5849`: Update setupext.py to solve issue #5846
* :ghpull:`5853`: Typo: fix some typos in patches.FancyArrowPatch
* :ghpull:`5842`: Allow image comparison outside tests module
* :ghpull:`5845`: V2.x merge to master
* :ghpull:`5813`: mathtext: no space after comma in brackets
* :ghpull:`5828`: FIX: overzealous clean up of imports
* :ghpull:`5826`: Strip spaces in properties doc after newline.
* :ghpull:`5815`: Properly minimize the rasterized layers
* :ghpull:`5752`: Reorganise mpl_toolkits documentation
* :ghpull:`5788`: Fix ImportError: No module named 'StringIO' on Python 3
* :ghpull:`5797`: Build docs on python3.5 with linkcheck running on python 2.7
* :ghpull:`5778`: Fix #5777.  Don't warn when applying default style
* :ghpull:`4857`: Toolbars keep history if axes change (navtoolbar2 + toolmanager)
* :ghpull:`5790`: Fix ImportError: No module named 'Tkinter' on Python 3
* :ghpull:`5789`: Index.html template. Only insert snippet if found
* :ghpull:`5783`: MNT: remove reference to deleted example
* :ghpull:`5780`: Choose offset text from ticks, not axes limits.
* :ghpull:`5776`: Add .noseids to .gitignore.
* :ghpull:`5466`: Fixed issue with ``rasterized`` not working for errorbar
* :ghpull:`5773`: Fix eb rasterize
* :ghpull:`5440`: Fix #4855: Blacklist rcParams that aren't style
* :ghpull:`5764`: BUG: make clabel obey fontsize kwarg
* :ghpull:`5771`: Remove no longer used Scikit image code
* :ghpull:`5766`: Deterministic LaTeX text in SVG images
* :ghpull:`5762`: Don't fallback to old ipython_console_highlighting
* :ghpull:`5728`: Use custom RNG for sketch path
* :ghpull:`5454`: ENH: Create an abstract base class for movie writers.
* :ghpull:`5600`: Fix #5572: Allow passing empty range to broken_barh
* :ghpull:`4874`: Document mpl_toolkits.axes_grid1.anchored_artists
* :ghpull:`5746`: Clarify that easy_install may be used to install all dependencies
* :ghpull:`5739`: Silence labeled data warning in tests
* :ghpull:`5732`: RF: fix annoying parens bug
* :ghpull:`5735`: Correct regex in filterwarnings
* :ghpull:`5640`: Warning message prior to fc-list command
* :ghpull:`5686`: Remove banner about updating styles in 2.0
* :ghpull:`5676`: Fix #5646: bump the font manager version
* :ghpull:`5719`: Fix #5693: Implemented is_sorted in C
* :ghpull:`5721`: Remove unused broken doc example axes_zoom_effect
* :ghpull:`5664`: Low-hanging performance improvements
* :ghpull:`5709`: Addresses issue #5704. Makes usage of parameters clearer
* :ghpull:`5716`: Fix #5715.
* :ghpull:`5690`: Fix #5687: Don't pass unicode to QApplication()
* :ghpull:`5707`: Fix string format substitution key missing error
* :ghpull:`5706`: Fix SyntaxError on Python 3
* :ghpull:`5700`: BUG: handle colorbar ticks with boundaries and NoNorm; closes #5673
* :ghpull:`5702`: Add missing substitution value
* :ghpull:`5701`: str.formatter invalid
* :ghpull:`5697`: TST: add missing decorator
* :ghpull:`5683`: Include outward ticks in bounding box
* :ghpull:`5688`: Improved documentation for FuncFormatter formatter class
* :ghpull:`5469`: Image options
* :ghpull:`5677`: Fix #5573: Use SVG in docs
* :ghpull:`4864`: Add documentation for mpl_toolkits.axes_grid1.inset_locator
* :ghpull:`5434`: Remove setup.py tests and adapt docs to use tests.py
* :ghpull:`5586`: Fix errorbar extension arrows
* :ghpull:`5653`: Update banner logo on main website
* :ghpull:`5667`: Nicer axes names in selector for figure options.
* :ghpull:`5672`: Fix #5670. No double endpoints in Path.to_polygon
* :ghpull:`5553`: qt: raise each new window
* :ghpull:`5594`: FIX: formatting in LogFormatterExponent
* :ghpull:`5588`: Adjust number of ticks based on length of axis
* :ghpull:`5671`: Deterministic svg
* :ghpull:`5659`: Change ``savefig.dpi`` and ``figure.dpi`` defaults
* :ghpull:`5662`: Bugfix for test_triage tool on Python 2
* :ghpull:`5661`: Fix #5660.  No FileNotFoundError on Py2
* :ghpull:`4921`: Add a quit_all key to the default keymap
* :ghpull:`5651`: Shorter svg files
* :ghpull:`5656`: Fix #5495.  Combine two tests to prevent race cond
* :ghpull:`5383`: Handle HiDPI displays in WebAgg/NbAgg backends
* :ghpull:`5307`: Lower test tolerance
* :ghpull:`5631`: WX/WXagg backend add code that zooms properly on a Mac with a Retina display
* :ghpull:`5644`: Fix typo in pyplot_scales.py
* :ghpull:`5639`: Test if a frame is not already being deleted before trying to Destroy.
* :ghpull:`5583`: Use data limits plus a little padding by default
* :ghpull:`4702`: sphinxext/plot_directive does not accept a caption
* :ghpull:`5612`: mathtext: Use DejaVu display symbols when available
* :ghpull:`5374`: MNT: Mailmap fixes and simplification
* :ghpull:`5516`: OSX virtualenv fixing by creating a simple alias
* :ghpull:`5546`: Fix #5524: Use large, but finite, values for contour extensions
* :ghpull:`5621`: Tst up coverage
* :ghpull:`5620`: FIX: quiver key pivot location
* :ghpull:`5607`: Clarify error when plot() args have bad shapes.
* :ghpull:`5604`: WIP: testing on windows and conda packages/ wheels for master
* :ghpull:`5611`: Update colormap user page
* :ghpull:`5587`: No explicit mathdefault in log formatter
* :ghpull:`5591`: fixed ordering of lightness plots and changed from getting lightness …
* :ghpull:`5605`: Fix DeprecationWarning in stackplot.py
* :ghpull:`5603`: Draw markers around center of pixels
* :ghpull:`5596`: No edges on filled things by default
* :ghpull:`5249`: Keep references to modules required in pgf LatexManager destructor
* :ghpull:`5589`:  return extension metadata
* :ghpull:`5566`: DOC: Fix typo in Axes.bxp.__doc__
* :ghpull:`5570`: use base64.encodestring on python2.7
* :ghpull:`5578`: Fix #5576: Handle CPLUS_INCLUDE_PATH
* :ghpull:`5555`: Use shorter float repr in figure options dialog.
* :ghpull:`5552`: Dep contourset vminmax
* :ghpull:`5433`: ENH: pass dash_offset through to gc for Line2D
* :ghpull:`5342`: Sort and uniquify style entries in figure options.
* :ghpull:`5484`: fix small typo in documentation about CheckButtons.
* :ghpull:`5547`: Fix #5545: Fix collection scale in data space
* :ghpull:`5500`: Fix #5475: Support tolerance when picking patches
* :ghpull:`5501`: Use facecolor instead of axisbg/axis_bgcolor
* :ghpull:`5544`: Revert "Fix #5524.  Use finfo.max instead of np.inf"
* :ghpull:`5146`: Move impl. of plt.subplots to Figure.add_subplots.
* :ghpull:`5534`: Fix #5524.  Use finfo.max instead of np.inf
* :ghpull:`5521`: Add test triage tool
* :ghpull:`5537`: Fix for broken maplotlib.test function
* :ghpull:`5539`: Fix docstring of violin{,plot} for return value.
* :ghpull:`5515`: Fix some theoretical problems with png reading
* :ghpull:`5526`: Add boxplot params to rctemplate
* :ghpull:`5533`: Fixes #5522, bug in custom scale example
* :ghpull:`5514`: adding str to force string in format
* :ghpull:`5512`: V2.0.x
* :ghpull:`5465`: Better test for isarray in figaspect(). Closes #5464.
* :ghpull:`5503`: Fix #4487: Take hist bins from rcParam
* :ghpull:`5485`: Contour levels must be increasing
* :ghpull:`4678`: TST: Enable coveralls/codecov code coverage
* :ghpull:`5437`: Make "classic" style have effect
* :ghpull:`5458`: Removed normalization of arrows in 3D quiver
* :ghpull:`5480`: make sure an autoreleasepool is in place
* :ghpull:`5451`: [Bug] masking of NaN Z values in pcolormesh
* :ghpull:`5453`: Force frame rate of FFMpegFileWriter input
* :ghpull:`5452`: Fix axes.set_prop_cycle to handle any generic iterable sequence.
* :ghpull:`5448`: Fix #5444: do not access subsuper nucleus _metrics if not available
* :ghpull:`5439`: Use DejaVu Sans as default fallback font
* :ghpull:`5204`: Minor cleanup work on navigation, text, and customization files.
* :ghpull:`5432`: Don't draw text when it's completely clipped away
* :ghpull:`5426`: MNT: examples: Set the aspect ratio to "equal" in the double pendulum animation.
* :ghpull:`5214`: Use DejaVu fonts as default for text and mathtext
* :ghpull:`5306`: Use a specific version of Freetype for testing
* :ghpull:`5410`: Remove uses of font.get_charmap
* :ghpull:`5407`: DOC: correct indentation
* :ghpull:`4863`: [mpl_toolkits] Allow "figure" kwarg for host functions in parasite_axes
* :ghpull:`5166`: [BUG] Don't allow 1d-arrays in plot_surface.
* :ghpull:`5360`: Add a new memleak script that does everything
* :ghpull:`5361`: Fix #347: Faster text rendering in Agg
* :ghpull:`5373`: Remove various Python 2.6 related workarounds
* :ghpull:`5398`: Updating 2.0 schedule
* :ghpull:`5389`: Faster image generation in WebAgg/NbAgg backends
* :ghpull:`4970`: Fixed ZoomPanBase to work with log plots
* :ghpull:`5387`: Fix #3314 assert mods.pop(0) fails
* :ghpull:`5385`: Faster event delegation in WebAgg/NbAgg backends
* :ghpull:`5384`: BUG: Make webagg work without IPython installed
* :ghpull:`5358`: Fix #5337.  Turn off --no-capture (-s) on nose
* :ghpull:`5379`: DOC: Fix typo, broken link in references
* :ghpull:`5371`: DOC: Add what's new entry for TransformedPatchPath.
* :ghpull:`5299`: Faster character mapping
* :ghpull:`5356`: Replace numpy funcs for scalars.
* :ghpull:`5359`: Fix memory leaks found by memleak_hawaii3.py
* :ghpull:`5357`: Fixed typo
* :ghpull:`4920`: ENH: Add TransformedPatchPath for clipping.

Issues (1130):

* :ghissue:`8599`: Pie Chart from CSV File
* :ghissue:`8586`: update errorbar in Matplotlib 2.0.0
* :ghissue:`8463`: wrong hatch color in legend
* :ghissue:`8558`: Rendering really large image
* :ghissue:`8312`: Matplotlib attempts to import PyQt4 when PyQt5 is not available
* :ghissue:`3528`: PS backend is not tested
* :ghissue:`4389`: Windows installer does not run -> restarts itself continually
* :ghissue:`8592`: Qt4 backend (PySide) seemingly tries to use Qt5
* :ghissue:`8579`: Python 2.7 travis build failing
* :ghissue:`8349`: [feature request] Accepting ``slice`` arguments in ``ax.set_xlim()`` (Python 3)
* :ghissue:`4379`: for the root example page, please provide more description
* :ghissue:`8571`: plt.subplots return is inconsistent
* :ghissue:`8570`: release 2.0.1 has qt4-incompatible code in backend_qt5.py
* :ghissue:`8569`: Superimposed markers when scatterpoints=1
* :ghissue:`8565`: Unexpected mixing of qt4backend and qt5backend
* :ghissue:`8563`: mpl2.0.1 seems to have broken Qt4Agg
* :ghissue:`8562`: 'QPixmap' object has no attribute 'setDevicePixelRatio'
* :ghissue:`8560`: Calling close() on a figure doesn't seem to close it
* :ghissue:`8174`: Update list of dependencies to build docs
* :ghissue:`8557`: Log scale on pcolor plot with only one tick
* :ghissue:`7412`: Documentation guidelines improvements 2
* :ghissue:`8541`: Generate a ``tutorials`` sphinx gallery
* :ghissue:`8223`: need to backport docathon PRs
* :ghissue:`7793`: Add pillow and graphviz to doc build dependencies
* :ghissue:`8501`: Remove false deprication warning
* :ghissue:`7206`: All examples should be MEP12/sphinx-gallery compliant
* :ghissue:`6457`: The first subplot is missized after ``savefig`` to a png file.
* :ghissue:`8521`: Rectangle patch not transformed correctly in polar plot
* :ghissue:`8542`: Inconsistent image size with savefig(...,type='png')
* :ghissue:`8445`: Cannot display np.array with dtype = np.float128
* :ghissue:`8508`: ``%matplotlib notebook`` show nothing, both 2d and 3d plot
* :ghissue:`7289`: ipython loses auto-show/auto-redraw behavior after call to ``plt.rcdefaults()``
* :ghissue:`6284`: ax.twinx().plot() will reset the x_limits if only an axvspan was used on ax
* :ghissue:`8527`: Confusing docstring in matplotlib.pyplot.bar() in version 2.0.0
* :ghissue:`8316`: Matplotlib User Interface Example Breaks With More Than Three Patches
* :ghissue:`7835`: Deprecate is_string_like
* :ghissue:`8524`: Errorbar limits arrow heads point in wrong direction on inverted axis
* :ghissue:`8520`: Documentation builds are failing due to sphinx-gallery changes
* :ghissue:`8514`: Can't plot with empty markers
* :ghissue:`8516`: .set_data() errors if number of points change
* :ghissue:`8517`: Log-scale ignores Formatter
* :ghissue:`8506`: text object clipping
* :ghissue:`6921`: "Error: local variable 'xdata' referenced before assignment" in legend_handler.py
* :ghissue:`8505`: plot window hangs and/or is generally unresponsive
* :ghissue:`8500`: plot disappears when moved to second monitor
* :ghissue:`7523`: Multi-line text instances differing in linespacing not rendered correctly
* :ghissue:`7725`: ``is_string_like`` returns True for numpy ``object`` arrays
* :ghissue:`8057`: markevery only accepts builtin integers, not numpy integers
* :ghissue:`8078`: plt.subplots crashes when handed fig_kw argument
* :ghissue:`8038`: Question on Path.contains_point/s
* :ghissue:`7688`: Edit axis with multiple figures causes freeze with Qt5 on Windows
* :ghissue:`7754`: Forgotten restore bounds?
* :ghissue:`5510`: autoscale context manager
* :ghissue:`6649`: UnboundLocalError in hist(x, bins, histtype='step', normed=1) on double entries in bins
* :ghissue:`6805`: Axes.hist with no data in range raises UnboundLocalError
* :ghissue:`7512`: ImportError: No module named Tkinter
* :ghissue:`6704`: Spacing in math text is broken (AIX specific)
* :ghissue:`8050`: Version 2.0.0_1 breaks OpenType font character spacing on PDF save
* :ghissue:`7924`: Python 3.6 deprecated escape sequences.
* :ghissue:`8030`: Unable to  intall matpotlib package using whl
* :ghissue:`8079`: Inconsistency between " and ' in the code
* :ghissue:`8128`: figure.Figure.autofmt_xdate applied to major xtick labels only
* :ghissue:`8168`: From matplotlib.font_manager, ImportError: cannot import name get_font
* :ghissue:`8220`: "search" doesn't find cmocean
* :ghissue:`8296`: Remove idle_event from examples/event_handling/idle_and_timeout.py
* :ghissue:`8242`: Investigate alternative svg renderers for the test suite
* :ghissue:`8424`: does matplotlib install in virtual environment work ?
* :ghissue:`8460`: matplotlib API docs missing container module
* :ghissue:`8467`: initialise imshow with zero array has unexpected side effects
* :ghissue:`7460`: Raise error if argument to xlim is invalid, e.g., nan
* :ghissue:`8465`: zorder values as a sequence are not respected by LineCollection
* :ghissue:`8457`: Allow to change base of LogNorm?
* :ghissue:`8406`: FancyArrow, error in the polygon coordinates for shape 'full'
* :ghissue:`8431`: Hatches filling an empty color contour not saved in pdf
* :ghissue:`7989`: 300% CPU on Raspberry Pi
* :ghissue:`537`: Orthogonal projection for mplot3d
* :ghissue:`8443`: No version when building from github archive
* :ghissue:`8444`: Matplotlib hangs with runtime error
* :ghissue:`8441`: ImportError: No module named _backend_gdk
* :ghissue:`8302`: Invalid certificate at https://matplotlib.org.
* :ghissue:`8432`: asd
* :ghissue:`8153`: Long lines in literal blocks run off the edge of the page
* :ghissue:`8160`: Using plt.ion with startup commands
* :ghissue:`8428`: Documentation: matplotlibrc example file confuses x and yticks.
* :ghissue:`8425`: MaxNLocator prune isn't working with decimals
* :ghissue:`8421`: Consistent deprecation of the hold kwarg of hlines and vlines
* :ghissue:`8427`: Matplotlib cannot find default matplotlib fonts on Scientific linux
* :ghissue:`7903`: Regression: imshow on geo axes produces an empty plot in matplotlib 2.0.0
* :ghissue:`8419`: Incorrect display of minor ticks in Log Scale plot with large font size
* :ghissue:`8418`: Matplotlib defaults to and bundles vera fonts that do not contain Greek letters
* :ghissue:`8073`: Please add Vega in perception documentation
* :ghissue:`8272`: Convert docstring of Axes.pie() into numpydoc
* :ghissue:`8416`: Python 3.4 image comparison test failure for ``mathtext_cm_52-expected.png``
* :ghissue:`8402`: plotting with TkAgg backend becomes unresponsive after a certain qt5agg backend import command
* :ghissue:`8412`: Data points not rendered for figures saved in vector formats
* :ghissue:`8397`: pyplot.subplots did not return the type of object specified in the documentation
* :ghissue:`8409`: loading pickled figure gives: AttributeError: 'CallbackRegistry' object has no attribute 'callbacks'
* :ghissue:`8111`: Issue with sub-setting minor-ticks at intermediate number of decades
* :ghissue:`8401`: weird bug when using custom formatter; tick labels overlapping
* :ghissue:`8398`: restore rebase documenation
* :ghissue:`7227`: Path effects for text outline is missing corners
* :ghissue:`3517`: Issue with non-ascii paths in font look up
* :ghissue:`8208`: make.py should not use ``os.system("sphinx-build ...")``
* :ghissue:`8386`: setting log major ticks leaves interfering minor tick labels
* :ghissue:`8370`: Simpler code for common plot setting (e.g. legend, lable, title, figsize)?
* :ghissue:`8385`: Make checkbox rectangles in CheckButtons widget have an edge outline
* :ghissue:`7785`: Passing a transposed array to patch.set_offsets()
* :ghissue:`8378`: ColorbarBase() is dpi dependent
* :ghissue:`8342`: Make ArrowStyle docstrings numpydoc compatible
* :ghissue:`7683`: Please add <shade = True> parameter to bar3d
* :ghissue:`8337`: axes set_position ignored if using tight_layout
* :ghissue:`8260`: test_backend_ps.py leaves temporary files in /tmp
* :ghissue:`8355`: Artifact at border with tricontourf and float32 positions
* :ghissue:`8330`: PyPy compatibility - __builtin__ is not iterable
* :ghissue:`8017`: Font family is not set on log-scaled tick labels
* :ghissue:`8317`: Fonts not changed in LaTeX mode (since version 2.0.0)
* :ghissue:`7293`: Isolated points missing in pdf
* :ghissue:`8348`: style.use not working for some cases
* :ghissue:`7655`: Event picking does not seem to work on polar bar plots
* :ghissue:`3540`: Pick events broken in log axes
* :ghissue:`8124`: Actually deprecate Axes.axesPatch, Figure.figurePatch
* :ghissue:`8290`: six environment polluted when misuse of matplotlib import
* :ghissue:`8230`: cache local freetype source
* :ghissue:`8332`: Importing Issue: "No module named externals"
* :ghissue:`8327`: Inconsistency between documentation and actual effect of the bar plot function
* :ghissue:`8197`: Matplotlib 2.0.0 crashes on plotting contour of array with two dimensions of size 1 in Python 3.4
* :ghissue:`8054`: is_scalar_or_string deprecated too early
* :ghissue:`8284`: Markers have compression artifacts
* :ghissue:`8294`: x marker is too big
* :ghissue:`8288`: che
* :ghissue:`7951`: matplotlib 2.0.0 not using matplotlibrc file in IPython
* :ghissue:`8012`: imshow interpolation uses masked values
* :ghissue:`8117`: Trying to plot only error bars (with no line connecting data points) results in empty plot
* :ghissue:`7953`: Cannot import _tkagg on windows 64 bits on 2.7
* :ghissue:`8225`: tight_layout does not work with set_visible(False)
* :ghissue:`8145`: Warning treated as error while generating docs
* :ghissue:`2304`: Add an argument rotate_labels to pie chart
* :ghissue:`8046`: Arc patch with starting and ending angle
* :ghissue:`8263`: error saving pcolormesh with shading=gouraud to eps
* :ghissue:`8034`: necked_tensile_specimen.png contains non-free color calibration profile
* :ghissue:`8231`: gitter badge at top of README.rst is broken
* :ghissue:`8141`: breaking change in dash verification in 2.0.0
* :ghissue:`8207`: Add early check for "dot" binary (graphviz) when building docs
* :ghissue:`8194`: Sample data not found
* :ghissue:`8186`: Put back gitter plain text link on README.rst
* :ghissue:`8198`: ticklabel font changes when using logscale
* :ghissue:`7616`: make 'dpi' optional for animation.MovieWriter.setup
* :ghissue:`8192`: %matplotlib inline doesn't work well with ipywidgets 6.0 interact
* :ghissue:`8189`: pip install matploblib broken
* :ghissue:`8177`: Add badges to README.rst
* :ghissue:`8180`: icu version problem with matplotlib 2
* :ghissue:`8169`: Autowrapping text doesn't work in "What's New in Matplotlib 1.5" example
* :ghissue:`8164`: Remove yield tests (now deprecated in pytest)
* :ghissue:`8159`: Doc: Restructure environment variables in ``Installing from source`` docs
* :ghissue:`8123`: Regenerate gitwash docs for improved syntax highlighting of non-python code sections
* :ghissue:`8147`: Use Agg backend by default if DISPLAY is not set
* :ghissue:`8146`: How to display D-stroke symbol in matplotlib
* :ghissue:`7905`: ytick locations different for 1.5.3 and 2.0.0
* :ghissue:`8121`: PNG output with PGF backend fails with pdftocairo exit code 99
* :ghissue:`8136`: If division by zero, python cannot convert float infinity to integer in ``get_tick_space()``
* :ghissue:`8067`: Coordinates of text not properly set in pgf files
* :ghissue:`8112`: Deprecate assert_str_equal
* :ghissue:`8122`: keyword labelrotation is not recognized
* :ghissue:`5151`: Horizontal lines in colorbars in PDF
* :ghissue:`4984`: errorbar incorrectly accepts and plots Nx2 shaped yerr
* :ghissue:`6593`: Feature request: filled error bar
* :ghissue:`7992`: Hatching doesn't respect alpha
* :ghissue:`7991`: Dotted grid lines in matplotlib v2.0.0 appear dashed
* :ghissue:`8015`: Document new testing procedure
* :ghissue:`8106`: Error in demo scripts: to_rgba: Invalid rgba arg "2" in style_sheets_reference.py
* :ghissue:`8105`: calling plt.hist() with np.nan value raises confusing error massage
* :ghissue:`5320`: Some searches in documentation result in no results
* :ghissue:`6042`: return ``_text`` property as  __repr__  for Text class
* :ghissue:`7171`: ``axes.boxplot`` does not have zorder kwarg
* :ghissue:`8098`: matplotlibrc doesen't work
* :ghissue:`8091`: Bug with plt.hist when min==max and values are >= 2**53
* :ghissue:`8087`: zorder is not respected by all parts of ``errorbar`` #1622 problem in matplotlib 2.0.0
* :ghissue:`7877`: add link to scipython book
* :ghissue:`8053`: save animation to mp4 fail
* :ghissue:`8076`: Matplotlib hatch color broken
* :ghissue:`8077`: ImportError: No module named 'matplotlib.rcsetup'
* :ghissue:`7686`: 'Extend' keyword produces colorbar of zero width
* :ghissue:`7886`: empty imshow crashes python
* :ghissue:`7901`: Allow multiple hatch colors in same figure
* :ghissue:`6708`: KnownFailure becomes an error with ``--processes=1`` flag
* :ghissue:`7899`: Behaviour of c=None is inconsistent in 2.0
* :ghissue:`8058`: Updating matplotlib to 2.0.0 causing problems when plotting: error/warning message "failed to get the current screen resources"
* :ghissue:`8051`: includes not-really-free BaKoMa fonts
* :ghissue:`8049`: Matplotlib 3D projection axis cannot be created because of missing rcParam[u'_internal.classic_mode']
* :ghissue:`6285`: ``plt.subplots()`` does not remove existing subplots when called on existing figure
* :ghissue:`8023`: numpy array not accepted for log scaled minor ticks
* :ghissue:`7967`: Catch or stop specgram warnings during tests
* :ghissue:`7813`: Qt5Agg backend not rendering nicely on Windows HiDPI display
* :ghissue:`6891`: Greek letter display error [1.5.1]
* :ghissue:`6393`: Pair of floats breaks plotting renderer (weirdest bug I've ever seen)
* :ghissue:`8027`: Log Scale Ticklabels Refuse to Die (Data Dependent)
* :ghissue:`5859`: savefig() as PNG get a different result than the image shown in ipython notebook(SVG probably)
* :ghissue:`5210`: Unexpected replacement of \right) with exlamation point in MathTextParser output
* :ghissue:`6902`: Include test files in coverage report
* :ghissue:`7756`: Cannot install the matplotlib 1.5.3 or 2.0.0rc2 on Mac OS Sierra, Python 3.6.0
* :ghissue:`5325`: Migrate to py.test
* :ghissue:`8016`: Unexpected HOME behavior after axis change
* :ghissue:`8009`: Need Python 3.6 wheels for matplotlib 1.5.1 on PyPI
* :ghissue:`8005`: Hex colours with alpha
* :ghissue:`7807`: ValueError when specifying marker vertices
* :ghissue:`7937`: Large TrueType font does not render correctly when saving in .pdf
* :ghissue:`7615`: Subscript/superscript sequence is too long with $\left. X \right|$
* :ghissue:`5287`: Warnings in doc build
* :ghissue:`6860`: The original xlim changed by twinx
* :ghissue:`6064`: specgram(x) should warn if x.size < 256
* :ghissue:`7964`: BUG: AxesImage.set_data([[]]) causes FloatingPointException
* :ghissue:`7963`: savefig PDF removing the negative sign from yticklabels
* :ghissue:`7955`: Failed install with "OSError: [Errno 12] Cannot allocate memory"
* :ghissue:`7958`: Matplotlib 2.0 cannot find PyQt5 (Windows)
* :ghissue:`7943`: ValueError when plotting Pandas Dataframe Summary
* :ghissue:`7940`: saving a square image constrained to the extent of axis without any border doesn't work
* :ghissue:`7636`: WX mouseevent assertion errors
* :ghissue:`7902`: Saving an unpickled figure.
* :ghissue:`6048`: AttributeError (no attribute 'callbacks') when setting attributes on pickle-loaded PatchCollection
* :ghissue:`7930`: KeyboardInterrupt while Matplotlib is displaying >= 2 figures causes X server crash
* :ghissue:`7874`: wheels not picking correct default backend
* :ghissue:`7906`: font_manager.get_fontconfig_fonts() reports a single item of all fonts concatenated
* :ghissue:`7922`: FT2Font do not close open file, leads to delayed ResourceWarning
* :ghissue:`7803`: tripcolor documentation rendering error .
* :ghissue:`7891`: pyplot.bar does not cycle through colors (>2.0.0b1)
* :ghissue:`7912`: matplotlib doesn't work  with numpy+mkl
* :ghissue:`7921`: Text rendered with MathText looks really ugly (version 2.0 vs. 1.5)
* :ghissue:`7919`: ~/.matplotlib/matplotlibrc not being read
* :ghissue:`7909`: Unit length quiver arrow not drawn with a unit length
* :ghissue:`7852`: _rrule maximum recursion depth exceeded on multiprocessing usage
* :ghissue:`7501`: Segmentation fault in QuadMeshGenerator on ppc64
* :ghissue:`7879`: UTF-8 error on import of matplotlib 1.5.1
* :ghissue:`7601`: color_cycle deprecation warning could provide more context to user
* :ghissue:`7875`: qt shims: QFontMetrics missing on PyQt5
* :ghissue:`7860`: widget radio buttons and check buttons no longer display outlines
* :ghissue:`7870`: DOC: FAQ out-of-date
* :ghissue:`7510`: better input validation on ``fill_between``
* :ghissue:`7867`: pyplot import error when current directory contains a file named sip.py
* :ghissue:`7248`: Adding names to the color in the new (Vega) default color cycle
* :ghissue:`6207`: axes_grid1.zoomed_inset_axes does not accept location as string
* :ghissue:`7775`: Locator tick_values for images
* :ghissue:`7810`: Dimensions sanity check in axes_rgb swaps x and y of shape when checking, prevents use with non-square images.
* :ghissue:`7704`: screenshots in the front page of devdocs are ugly
* :ghissue:`7746`: imshow should silence warnings on invalid values, at least when masked
* :ghissue:`7661`: document that imshow now respects scale
* :ghissue:`6820`: nonsensical error message for invalid input to plt.bar
* :ghissue:`7814`: Legend for lines created using ``LineCollection`` show different handle line scale.
* :ghissue:`7816`: re-enable or delete xmllint tests
* :ghissue:`7802`: plt.stackplot not working for integer input with non-default 'baseline' parameters
* :ghissue:`6149`: travis dedup
* :ghissue:`7822`: Weird stroke join with patheffects
* :ghissue:`7784`: Simple IndexError in artist.setp if empty list is passed
* :ghissue:`3354`: Unecessary arguement in GraphicsContextBase get_linestyle
* :ghissue:`7820`: Figure.savefig() not respecting bbox_inches='tight' when dpi specified
* :ghissue:`7715`: Can't import pyplot in matplotlib 2.0 rc2
* :ghissue:`7745`: Wheel distributables include unnecessary files
* :ghissue:`7812`: On MacOS Sierra with IPython, inconsistent results with %gui, %matplotlib magic commands and --gui, and --matplotlib command-line options for ipython and qtconsole; complete failure of qtconsole inline figures
* :ghissue:`7808`: Basemap uses deprecated methods
* :ghissue:`7487`: Funny things happen when a rectangle with negative width/height is passed to ``axes()``
* :ghissue:`7649`: --nose-verbose isn't a correct option for nose
* :ghissue:`7656`: imsave ignores origin option
* :ghissue:`7792`: test_png.test_pngsuite.test fails on ppc64 (big-endian)
* :ghissue:`7788`: Colorbars contain no colors when created on ppc64 (big-endian)
* :ghissue:`4285`: plt.yscale("log") gives FloatingPointError: underflow encountered in multiply
* :ghissue:`7724`: Can't import Matplotlib.widgets.TextBox
* :ghissue:`7798`: ``test_psd_csd_equal`` fails for 12 (but not all) of the ``test_mlab.spectral_testcase`` s on ppc64 (big-endian)
* :ghissue:`7778`: Different font size between math mode and regular text
* :ghissue:`7777`: mpl_toolkits.basemap: ValueError: level must be >= 0
* :ghissue:`4353`: different behaviour of zoom while using ginput with MouseEvent vs KeyEvent
* :ghissue:`4380`: horizontalalignment 'left' and 'right' do not handle spacing consistently
* :ghissue:`7393`: ``subplot()``: incorrect description of deletion of overlapping axes in the docs
* :ghissue:`7759`: matplotlib dynamic plotting
* :ghissue:`2025`: TkAgg build seems to favor Framework Tcl/Tk on OS-X
* :ghissue:`3991`: SIGINT is ignored by MacOSX backend
* :ghissue:`2722`: limited number of grid lines in matplotlib?
* :ghissue:`3983`: Issue when trying to plot points with transform that requires more/fewer coordinates than it returns
* :ghissue:`7734`: inconsistent doc regarding keymap.fullscreen default value
* :ghissue:`7761`: Deprecation warning for finance is very unclear
* :ghissue:`7223`: matplotlib.rcsetup docs
* :ghissue:`3917`: OS X Cursor Not working on command line
* :ghissue:`4038`: Hist Plot Normalization should allow a 'Per Bin' Normalization
* :ghissue:`3486`: Update Selection Widgets
* :ghissue:`7457`: Improvements to pylab_examples/stock_demo.py
* :ghissue:`7755`: Can't open figure
* :ghissue:`7299`: Raise an error or a warning when ylim's min == 0 and yscale == "log"
* :ghissue:`4977`: Improve resolution of canvas on HiDPI with PyQt5 backend
* :ghissue:`7495`: Missing facecolor2d attribute
* :ghissue:`3727`: plot_date() does not work with x values of type pandas.Timestamp (pandas version 0.15.0)?
* :ghissue:`3368`: Variable number of ticks with LogLocator for a fixed number of tick labels displayed
* :ghissue:`1835`: docstrings of cross-correlation functions (acorr and xcorr) need clarification
* :ghissue:`6972`: quiverkey problem when angles=array
* :ghissue:`6617`: Problem of fonts with LaTeX rendering due to fonts-lyx package
* :ghissue:`7717`: make all deprecation warnings be ``mplDeprecation`` instances
* :ghissue:`7662`: eventplot legend fails (linewidth)
* :ghissue:`7673`: Baseline image reuse breaks parallel testing
* :ghissue:`7666`: Default scaling of x-axis in specgram() is incorrect (i.e. the default value for the ``xextent`` parameter)
* :ghissue:`7709`: Running into problems in seaborn after upgrading matpltolib
* :ghissue:`7684`: 3-D scatter plot disappears when overlaid over a 3-D surface plot.
* :ghissue:`7630`: Unicode issue in matplotlib.dates
* :ghissue:`7678`: add link to bokeh/colorcet
* :ghissue:`2078`: linespacing of multiline texts.
* :ghissue:`6727`: scipy 2016 sprint ideas
* :ghissue:`3212`: Why are numpoints and scatterpoints two different keywords?
* :ghissue:`7697`: Update INSTALL file to include py3.6
* :ghissue:`4428`: Hyphen as a subscript doesn't appear at certain font sizes
* :ghissue:`2886`: The wrong \Game symbol is used
* :ghissue:`7603`: scatter ``color`` vs ``c``
* :ghissue:`7660`: 2.0rc2:  title too close to frame?
* :ghissue:`7672`: standardize classic/v2.x order is docs
* :ghissue:`7680`: OverflowError: Python int too large to convert to C long during ploting simple numbers on debian testing
* :ghissue:`7664`: BUG: ``super`` requires at least 1 argument
* :ghissue:`7669`: rc on conda-forge
* :ghissue:`5363`: Warnings from test_contour.test_corner_mask
* :ghissue:`7663`: BUG: Can't import ``matplotlib._backports``
* :ghissue:`7647`: Decorator for deprecation ignores arguments other than 'message'
* :ghissue:`5806`: FutureWarning with Numpy 1.10
* :ghissue:`6480`: Setting markeredgecolor raises a warning
* :ghissue:`7653`: legend doesn't show all markers
* :ghissue:`7643`: Matplotlib 2.0 deprecations
* :ghissue:`7642`: imshow seems to "shift" grid.
* :ghissue:`7633`: All attempts to plot fail with "OverflowError: Python int too large to convert to C long"
* :ghissue:`7637`: Stacked 2D plots with interconnections in Matplotlib
* :ghissue:`7353`: auto legend position changes upon saving the figure
* :ghissue:`7626`: Saturation mask for imshow()
* :ghissue:`7623`: potential bug with plt.arrow and plt.annotate when setting linestyle via tuples
* :ghissue:`7005`: rcParams['font.size'] is consulted at render time
* :ghissue:`7587`: BUG: shared log axes lose _minpos and revert to default
* :ghissue:`7493`: Plotting zero values with logarithmic axes triggers OverflowError, Matplotlib hangs permanently
* :ghissue:`7595`: math domain error using symlog norm
* :ghissue:`7588`: 2.0.0rc1  cannot import name '_macosx'
* :ghissue:`2051`: Consider making default verticalalignment ``baseline``
* :ghissue:`4867`: Add additional minor labels in log axis with a span less than two decades
* :ghissue:`7489`: Too small axis arrow when savefig to png
* :ghissue:`7611`: UnicodeDecodeError when using matplotlib save SVG file and open it again
* :ghissue:`7592`: font cache: a possibility to disable building it
* :ghissue:`5836`: Repeated warning about fc-list
* :ghissue:`7609`: The best channel to ask questions related to using matplotlib
* :ghissue:`7141`: Feature request: auto locate minor ticks on log scaled color bar
* :ghissue:`3489`: matplotlib scatter shifts color codes when NaN is present
* :ghissue:`4414`: Specifying histtype='stepfilled' and normed=True when using plt.hist causes ymax to be set incorrectly
* :ghissue:`7597`: python  complain about "This application failed to start because it could not find or load the Qt platform plugin  'xcb' "  after an update of matplotlib
* :ghissue:`7578`: Validate steps input to ``MaxNLocator``
* :ghissue:`7590`: Subtick labels are not disabled in classic style
* :ghissue:`6317`: PDF file generation is not deterministic - results in different outputs on the same input
* :ghissue:`6543`: Why does fill_betweenx  not  have interpolate?
* :ghissue:`7437`: Broken path to example with strpdate2num
* :ghissue:`7593`: Issue: Applying Axis Limits
* :ghissue:`7591`: Number of subplots in mpl.axes.Subplot object
* :ghissue:`7056`: setup.py --name and friends broken
* :ghissue:`7044`: location of convert in rcparams on windows
* :ghissue:`6813`: avoid hiding edge pixels of images
* :ghissue:`7579`: OS X libpng incompatability
* :ghissue:`7576`: v2.0.0rc1 conda-forge dependency issue
* :ghissue:`7558`: Colorbar becomes 0 to 1 after colorbar ax.yaxis.set_major_formatter
* :ghissue:`7526`: Cannot Disable TkAgg Backend
* :ghissue:`6565`: Questionable margin-cancellation logic
* :ghissue:`7175`: new margin system doesn't handle negative values in bars
* :ghissue:`5201`: issue with colorbar using LogNorm and extend='min'
* :ghissue:`6580`: Ensure install requirements in documentation are up to date before release
* :ghissue:`5654`: Update static images in docs to reflect new style
* :ghissue:`7553`: frange returns a last value greater than limit
* :ghissue:`5961`: track bdist_wheel release and remove the workaround when 0.27 is released
* :ghissue:`7554`: TeX formula rendering broken
* :ghissue:`6885`: Check if ~/.matplotlib/ is a symlink to ~/.config/matplotlib/
* :ghissue:`7202`: Colorbar with SymmetricalLogLocator : issue when handling only negative values
* :ghissue:`7542`: Plotting masked array lose data points
* :ghissue:`6678`: dead links in docs
* :ghissue:`7534`: nbagg doesn't change figure's facecolor
* :ghissue:`7535`: Set return of type Axes in Numpydoc docstring return type hint for Figure.add_subplot and Figure.add_axes to help jedi introspection
* :ghissue:`7443`: pdf doc build is sort of broken
* :ghissue:`7521`: Figure.show() fails with Qt5Agg on Windows (plt.show() works)
* :ghissue:`7423`: Latex cache error when building docs
* :ghissue:`7519`: plt.table() without any kwargs throws exception
* :ghissue:`3070`: remove hold logic from library
* :ghissue:`1910`: Pylab contourf plot using Mollweide projection create artefacts
* :ghissue:`5350`: Minor Bug on table.py
* :ghissue:`7518`: Incorrect transData in a simple plot
* :ghissue:`6985`: Animation of contourf becomes extremely slow
* :ghissue:`7508`: Legend not displayed
* :ghissue:`7484`: Remove numpy 1.6 specific work-arounds
* :ghissue:`6746`: Matplotlib.pyplot 2.0.0b2 fails to import with Conda Python 3.5 on OS X
* :ghissue:`7505`: Default color cycler for plots should have more than 8 colors
* :ghissue:`7185`: Hexbin default edgecolors kwarg is misnamed
* :ghissue:`7478`: 'alpha' kwarg overrides facecolor='none' when plotting circle
* :ghissue:`7375`: Patch edgecolor of a legend item does not follow look of figure
* :ghissue:`6873`: examples/api/skewt.py is not displaying the right part of the grid by default
* :ghissue:`6773`: Shifted image extents in 2.0.0.b3
* :ghissue:`7350`: Colors drawn outside axis for hist2d
* :ghissue:`7485`: Is there a way to subclass the zoom() function from the NavigationToolbar backends and modify its mouse button definition?
* :ghissue:`7396`: Bump numpy minimal version to 1.7.0?
* :ghissue:`7466`: missing trigger for autoscale
* :ghissue:`7477`: v2.0.0b4 fails to build with python-3.5: Requires pygtk
* :ghissue:`7113`: Problems with anatomy figure on v2.x
* :ghissue:`6722`: Text: rotation inconsistency
* :ghissue:`7244`: Codecov instead of coveralls?
* :ghissue:`5076`: RuntimeError: LaTeX was not able to process the following string: 'z=$\\\\mathregular{{}^{}_{\\\\}}$' in matplotlib
* :ghissue:`7450`: Using Matplotlib in Abaqus
* :ghissue:`7314`: Better error message in scatter plot when len(x) != len(c)
* :ghissue:`7432`: Failure to re-render after Line2D.set_color
* :ghissue:`6695`: support markdown or similar
* :ghissue:`6228`: Rasterizing patch changes filling of hatches in pdf backend
* :ghissue:`3023`: contourf hatching and saving to pdf
* :ghissue:`4108`: Hatch pattern changes with dpi
* :ghissue:`6968`: autoscale differences between 1.5.1 and 2.0.0b3
* :ghissue:`7452`: ``test_log_margins`` test failure
* :ghissue:`7143`: spurious warning with nans in log-scale plot
* :ghissue:`7448`: Relative lengths in 3d quiver plots
* :ghissue:`7426`: prop_cycler validation over-zealous
* :ghissue:`6899`: ``savefig`` has sideeffects
* :ghissue:`7440`: Confusing examples in ``annotation_demo2``
* :ghissue:`7441`: Loading a matplotlib figure pickle within a tkinter GUI
* :ghissue:`6643`: Incorrect margins in log scale
* :ghissue:`7356`: plt.hist does not obey the hist.bins rcparams
* :ghissue:`6845`: SVG backend: anomaly in gallery scatter legend
* :ghissue:`6527`: Documentation issues
* :ghissue:`7315`: Spectral vs spectral Deprecation warning
* :ghissue:`7428`: from matplotlib.backends import _tkagg raises AttributeError: 'module' object has no attribute '__file__'
* :ghissue:`7431`: %matplotlib notebook offsetting sns.palplot
* :ghissue:`7361`: add multi-process flag as ``-j`` to ``test.py``
* :ghissue:`7406`: NaN causes plt.vlines to not scale y limits
* :ghissue:`7104`: set offset threshold to 4
* :ghissue:`7404`: obnoxious double warning at each script startup
* :ghissue:`7373`: Regression in imshow
* :ghissue:`7166`: Hatching in legends is broken
* :ghissue:`6939`: wspace is not "The amount of width reserved for blank space between subplots" as documented
* :ghissue:`4026`: control hatch linewidth and fill border linewidth separately
* :ghissue:`7390`: MAINT move the examples from doc/pyplots to examples and make them reproducible
* :ghissue:`7198`: style blacklist includes hardcopy.docstring but it should be docstring.hardcopy
* :ghissue:`7391`: How to apply ax.margins to current axes limits?
* :ghissue:`7234`: Improving documentation: Tests failing on a osx setup
* :ghissue:`7379`: Mp4's generated by movie writer do not appear work in browser
* :ghissue:`6870`: Figure is unpicklable after ``savefig``
* :ghissue:`6181`: When using Agg driver, pickling fails with TypeError after writing figure to PDF
* :ghissue:`6926`: SVG backend closes BytesIO on print if were ``usetex=True`` and ``cleanup`` decorator used
* :ghissue:`3899`: Pickle not working in interactive ipython session
* :ghissue:`7251`: Improve violin plot demo
* :ghissue:`7146`: symlog scale no longer shows labels on the negative side
* :ghissue:`3420`: simple plotting of numpy 2d-arrays
* :ghissue:`7287`: Make matplotlib.use() report where the backend was set first, in case of conflict
* :ghissue:`7305`: RuntimeError In FT2Font with NISC18030.ttf
* :ghissue:`7351`: Interactive mode seems to be broken on MacOSX
* :ghissue:`7313`: Axes3D.plot_surface with meshgrid args stopped working
* :ghissue:`7281`: rcparam encoding test is broken
* :ghissue:`7345`: Annotation minor issue in the example linestyles.py
* :ghissue:`7210`: variable frame size support in animation is a misfeature
* :ghissue:`5222`: legend--plot handle association
* :ghissue:`7312`: get_facecolors() reports incorrect colors
* :ghissue:`7332`: plot range
* :ghissue:`1719`: Can't pickle bar plots: Failed to pickle attribute "gridline"
* :ghissue:`6348`: When I run a file that uses matplolib animation, I keep getting this error. Using OS X, Python 2.7, installed Python from python.org then used homebrew. Matplotlib install from pip.
* :ghissue:`5386`: Error loading fonts on OSX 10.11
* :ghissue:`6448`: hist step UnboundLocalError
* :ghissue:`6958`: Document the verts kwarg to scatter
* :ghissue:`7204`: Integrate sphinx-gallery to our user documentation
* :ghissue:`7325`: Anaconda broken after trying to install matplotlib 2.0 beta (ubuntu)
* :ghissue:`7218`: v1.5.3: marker=None no longer works in plot()
* :ghissue:`7271`: BUG: symmetric kwarg in locator is not honored by contourf
* :ghissue:`7095`: _preprocess_data interferes in the docstrings Notes section
* :ghissue:`7283`: DOC: Misrendered URLs in the development_worflow section of devdocs.
* :ghissue:`7109`: backport #7108 to v2.x
* :ghissue:`7265`: Image watermark hidden by Axes in example
* :ghissue:`7263`: axes.bxp fails without fliers
* :ghissue:`7274`: Latex greek letters in axis labels
* :ghissue:`7186`: matplotlib 1.5.3 raise TypeError: 'module' object is not subscriptable on pylab.py
* :ghissue:`6865`: custom_projection_example.py is completely out of date
* :ghissue:`7224`: FancyArrowPatch linestyle always solid
* :ghissue:`7215`: BUG: bar deals with bytes and string x data in different manners, both that are unexpected
* :ghissue:`7270`: Pylab import
* :ghissue:`7230`: subplots docstring: no example of NxN grid
* :ghissue:`7269`: documentation: texinfo markup error in matplotlib 1.4.3 and matplotlib 1.5.3
* :ghissue:`7264`: matplotlib dependency cycle matplotlib <- ipython <- matplotlib - how to resolve?
* :ghissue:`7261`: Legend not displayed in Plot-Matplot lib
* :ghissue:`7260`: Unknown exception in resize
* :ghissue:`7259`: autoscaling of yaxis fails
* :ghissue:`7257`: How can plot a figure with matplotlib like this?
* :ghissue:`3959`: setting up matplotlib for development
* :ghissue:`7240`: New tests without baseline images never produce a result
* :ghissue:`7156`: Inverted imshow using Cairo backend
* :ghissue:`6723`: How to customize violinplots?
* :ghissue:`5423`: fill_between wrong edge line color
* :ghissue:`5999`: Math accents are not correctly aligned
* :ghissue:`1039`: Cairo backend marker/line style
* :ghissue:`7174`: default value of ``lines.dash_capstyle``
* :ghissue:`7246`: Inconsistent behaviour of  ``subplots`` for one and more-than-one axes
* :ghissue:`7228`: axes tick_params label color not respected when showing scientific notation for axes scale
* :ghissue:`7225`: get_geometry() wrong if subplots are nested (e.g., subplots with colorbars)
* :ghissue:`7221`: Why does pyplot display wrong grayscale image?
* :ghissue:`7191`: BUG: Animation bugs fixed in master should be backported to 2.x
* :ghissue:`7017`: Doc typos in "Our favorite recipes"
* :ghissue:`3343`: Issues with ``imshow`` and  RGBA values
* :ghissue:`7157`: should fill_between Cycle?
* :ghissue:`7159`: test_colors.test_Normalize fails in 2.0.0b4 on Fedora rawhide/aarch64 (ARMv8)
* :ghissue:`7201`: RGBA values produce different result for imshow and for markers
* :ghissue:`3232`: Navigation API Needed
* :ghissue:`7001`: Default log ticker can make too many ticks
* :ghissue:`806`: Provide an option for the Animation class to retain the previously rendered frames
* :ghissue:`6135`: matplotlib.animate writes png frames in cwd instead of temp files
* :ghissue:`7189`: graph not showing when I set format to line
* :ghissue:`7080`: Difference in symbol sizes using Mathtext with stixsans
* :ghissue:`7162`: _axes.py linestyle_map unused
* :ghissue:`7163`: pyplot.subplots() is slow
* :ghissue:`7161`: matplotlib.ticker.FormatStrFormatter clashes with ax2.set_yticklabels when dual y-axis is used
* :ghissue:`6549`: Log scale tick labels are overlapping
* :ghissue:`7154`: bar graph with nan values leads to "No current point in closepath" in evince
* :ghissue:`7149`: unable to save .eps plot
* :ghissue:`7090`: fix building pdf docs
* :ghissue:`6996`: FontProperties size and weight ignored by figure.suptitle
* :ghissue:`7139`: float128s everywhere for dates?
* :ghissue:`7083`: DOC: Clarify the relationship between ``plot`` and ``scatter``
* :ghissue:`7125`: Import Error on matplotlib.pyplot: PyQt4
* :ghissue:`7124`: Updated matplotlib 1.5.3 broken in default Anaconda channel
* :ghissue:`6429`: Segfault when calling show() after using Popen (test code inside)
* :ghissue:`7114`: BUG: ax.tick_params change in tick length does not adjust tick labels
* :ghissue:`7120`: Polar plot cos(2x)
* :ghissue:`7081`: enh: additional colorblind-friendly colormaps
* :ghissue:`7103`: Problem with discrete ``ListedColormaps`` when more than 4 colors are present
* :ghissue:`7115`: Using matplotlib without Tkinter
* :ghissue:`7106`: Wrong reader in mathext.py
* :ghissue:`7078`: imshow() does not interpret aspect/extent when interpolation='none' in svg output
* :ghissue:`6616`: Keyboard shortcuts for toggling minor ticks grid and opening figureoptions window
* :ghissue:`7105`: Can't pickle <type 'instancemethod'>
* :ghissue:`7086`: DOC (released) style is badly broken on the user doc.
* :ghissue:`7065`: backport #7049
* :ghissue:`7091`: v2.0.0b4 breaks viscm
* :ghissue:`7043`: BUG: LogLocator.set_params is broken
* :ghissue:`7070`: autoscale does not work for axes added by fig.add_axes()
* :ghissue:`3645`: Proposal: Add rc setting to control dash spacing
* :ghissue:`7009`: No good way to disable SpanSelector
* :ghissue:`7040`: It is getting increasingly difficult to build the matplotlib documentation
* :ghissue:`6964`: Docstring for ArtistAnimation is incorrect
* :ghissue:`6965`: ArtistAnimation cannot animate Figure-only artists
* :ghissue:`7062`: remove the contour on a Basemap object
* :ghissue:`7061`: remove the contour on Basemap
* :ghissue:`7054`: Whether the new version 2.0 will support high-definition screen?
* :ghissue:`7053`: When will release 2.0 official version?
* :ghissue:`6797`: Undefined Symbol Error On Ubuntu
* :ghissue:`6523`: matplotlib-2.0.0b1 test errors on Windows
* :ghissue:`4753`: rubber band in qt5agg slow
* :ghissue:`6959`: extra box on histogram plot with a single value
* :ghissue:`6816`: Segmentation fault on Qt5Agg when using the wrong linestyle
* :ghissue:`4212`: Hist showing wrong first bin
* :ghissue:`4602`: bar / hist : gap between first bar and other bars with lw=0.0
* :ghissue:`6641`: Edge ticks sometimes disappear
* :ghissue:`7041`: Python 3.5.2 crashes when launching matplotlib 1.5.1
* :ghissue:`7028`: Latex Greek fonts not working in legend
* :ghissue:`6998`: dash pattern scaling with linewidth should get it's own rcParam
* :ghissue:`7021`: How to prevent matplotlib from importing qt4 libraries when only
* :ghissue:`7020`: Using tick_right() removes any styling applied to tick labels.
* :ghissue:`7018`: Website Down
* :ghissue:`6785`: Callbacks of draggable artists should check that they have not been removed
* :ghissue:`6783`: Draggable annotations specified in offset coordinates switch to figure coordinates after dragging
* :ghissue:`7015`: pcolor() not using "data" keyword argument
* :ghissue:`7014`: matplotlib works well in ipython note book but can't display in a terminal running
* :ghissue:`6999`: cycler 0.10 is required due to change_key() usage
* :ghissue:`6794`: Incorrect text clipping in presence of multiple subplots
* :ghissue:`7004`: Zooming with a large range in y-values while using the linestyle "--" is very slow
* :ghissue:`6828`: Spikes in small wedges of a pie chart
* :ghissue:`6940`: large memory leak in new contour routine
* :ghissue:`6894`: bar(..., linewidth=None) doesn't display bar edges with mpl2.0b3
* :ghissue:`6989`: bar3d no longer allows default colors
* :ghissue:`6980`: problem accessing canvas on MacOS 10.11.6 with matplotlib 2.0.0b3
* :ghissue:`6804`: Histogram of xarray.DataArray can be extremely slow
* :ghissue:`6859`: Update URL for links to ggplot
* :ghissue:`6852`: Switching to log scale when there is no positive data crashes the Qt5 backend, causes inconsistent internal state in others
* :ghissue:`6740`: PGF Backend: Support interpolation='none'?
* :ghissue:`6665`: regression: builtin latex rendering doesn't find the right mathematical fonts
* :ghissue:`6984`: plt.annotate(): segmentation fault when coordinates are too high
* :ghissue:`6979`: plot won't show with plt.show(block=False)
* :ghissue:`6981`: link to ggplot is broken...
* :ghissue:`6975`: [Feature request] Simple ticks generator for given range
* :ghissue:`6905`: pcolorfast results in invalid cursor data
* :ghissue:`6970`: quiver problems when angles is an array of values rather than 'uv' or 'xy'
* :ghissue:`6966`: No Windows wheel available on PyPI for new version of matplotlib (1.5.2)
* :ghissue:`6721`: Font cache building of matplotlib blocks requests made to HTTPd
* :ghissue:`6844`: scatter edgecolor is broken in Matplotlib 2.0.0b3
* :ghissue:`6849`: BUG: endless loop with MaxNLocator integer kwarg and short axis
* :ghissue:`6935`: matplotlib.dates.DayLocator cannot handle invalid input
* :ghissue:`6951`: Ring over A in \AA is too high in Matplotlib 1.5.1
* :ghissue:`6960`: axvline is sometimes not shown
* :ghissue:`6473`: Matplotlib manylinux wheel - ready to ship?
* :ghissue:`5013`: Add Hershey Fonts a la IDL
* :ghissue:`6953`: ax.vlines adds unwanted padding, changes ticks
* :ghissue:`6946`: No Coveralls reports on GitHub
* :ghissue:`6933`: Misleading error message for matplotlib.pyplot.errorbar()
* :ghissue:`6945`: Matplotlib 2.0.0b3 wheel can't load libpng in OS X 10.6
* :ghissue:`3865`: Improvement suggestions for matplotlib.Animation.save('video.mp4')
* :ghissue:`6932`: Investigate issue with pyparsing 2.1.6
* :ghissue:`6941`: Interfering with yahoo_finance
* :ghissue:`6913`: Cant get currency from yahoo finance with matplotlib
* :ghissue:`6901`: Add API function for removing legend label from graph
* :ghissue:`6510`: 2.0 beta: Boxplot patches zorder differs from lines
* :ghissue:`6911`: freetype build won't become local
* :ghissue:`6866`: examples/misc/longshort.py is outdated
* :ghissue:`6912`: Matplotlib fail to compile matplotlib._png
* :ghissue:`1711`: Autoscale to automatically include a tiny margin with ``Axes.errorbar()``
* :ghissue:`6903`: RuntimeError('Invalid DISPLAY variable') - With docker and django
* :ghissue:`6888`: Can not maintain zoom level when left key is pressed
* :ghissue:`6855`: imsave-generated PNG files missing edges for certain resolutions
* :ghissue:`6479`: Hexbin with log scale takes extent range as logarithm of the data along the log axis
* :ghissue:`6795`: suggestion: set_xticklabels and set_yticklabels default to current labels
* :ghissue:`6825`: I broke imshow(<signed integer array>) :-(
* :ghissue:`6858`: PyQt5 pyplot error
* :ghissue:`6853`: PyQt5 (v5.7) backend - TypeError upon calling figure()
* :ghissue:`6835`: Which image formats to build in docs.
* :ghissue:`6856`: Incorrect plotting for versions > 1.3.1 and GTK.
* :ghissue:`6838`: Figures not showing in interactive mode with macosx backend
* :ghissue:`6846`: GTK Warning
* :ghissue:`6839`: Test ``test_pickle.test_complete`` is broken
* :ghissue:`6691`: rcParam missing tick side parameters
* :ghissue:`6833`: plot contour with levels from discrete data
* :ghissue:`6636`: DOC: gallery supplies 2 pngs, neither of which is default
* :ghissue:`3896`: dates.date2num bug with daylight switching hour
* :ghissue:`6685`: 2.0 dev legend breaks on scatterplot
* :ghissue:`3655`: ensure removal of font cache on version upgrade
* :ghissue:`6818`: Failure to build docs: unknown property
* :ghissue:`6798`: clean and regenerate travis cache
* :ghissue:`6782`: 2.x: Contour level count is not respected
* :ghissue:`6796`: plot/lines not working for datetime objects that span old dates
* :ghissue:`6660`: cell focus/cursor issue when plotting to nbagg
* :ghissue:`6775`: Last figure in http://matplotlib.org/users/pyplot_tutorial.html is not displayed correctly
* :ghissue:`5981`: Increased tick width in 3D plots looks odd
* :ghissue:`6771`: ImportError: No module named artist
* :ghissue:`6289`: Grids are not rendered in backend implementation
* :ghissue:`6621`: Change in the result of test_markevery_linear_scales_zoomed
* :ghissue:`6515`: Dotted grid lines in v2.0.0b1
* :ghissue:`6511`: Dependencies in installation of 2.0.0b1
* :ghissue:`6668`: “Bachelor's degrees…” picture in the gallery is cropped
* :ghissue:`6751`: Tableau style
* :ghissue:`6742`: import matplotlib.pyplot as plt throws an erro
* :ghissue:`6097`: anaconda package missing nose dependency
* :ghissue:`6299`: savefig() to eps/pdf does not work
* :ghissue:`6387`: import matplotlib causes UnicodeDecodeError
* :ghissue:`6471`: Colorbar label position different when executing a block of code
* :ghissue:`6732`: Adding ``pairplot`` functionality?
* :ghissue:`6749`: Step diagram does not support xlim() and ylim()
* :ghissue:`6748`: Step diagram does not suppot
* :ghissue:`6615`: Bad event index for step plots
* :ghissue:`6588`: Different line styles between PNG and PDF exports.
* :ghissue:`6693`: linestyle="None" argument for fill_between() doesn't work
* :ghissue:`6592`: Linestyle pattern depends on current style, not style set at creation
* :ghissue:`5430`: Linestyle: dash tuple with offset
* :ghissue:`6728`: Can't install matplotlib with specific python version
* :ghissue:`6546`: Recommendation to install packages for various OS
* :ghissue:`6536`: get_sample_data() in cbook.py duplicates code from _get_data_path() __init__.py
* :ghissue:`3631`: Better document meaning of notches in boxplots
* :ghissue:`6705`: The test suite spends 20% of it's time in ``gc.collect()``
* :ghissue:`6698`: Axes3D scatter crashes without alpha keyword
* :ghissue:`5860`: Computer Modern Roman should be the default serif when using TeX backend
* :ghissue:`6702`: Bad fonts crashes matplotlib on startup
* :ghissue:`6671`: Issue plotting big endian images
* :ghissue:`6196`: Qt properties editor discards color alpha
* :ghissue:`6509`: pylab image_masked is broken
* :ghissue:`6657`: appveyor is failing on pre-install
* :ghissue:`6610`: Icons for Tk are not antialiased.
* :ghissue:`6687`: Small issues with the example ``polar_scatter_demo.py``
* :ghissue:`6541`: Time to deprecate the GTK backend
* :ghissue:`6680`: Minor typo in the docstring of ``IdentityTransform``?
* :ghissue:`6670`: plt.text object updating incorrectly with blit=False
* :ghissue:`6646`: Incorrect fill_between chart when use set_xscale('log')
* :ghissue:`6540`: imshow(..., alpha=0.5) produces different results in 2.x
* :ghissue:`6650`: fill_between() not working properly
* :ghissue:`6566`: Regression: Path.contains_points now returns uint instead of bool
* :ghissue:`6624`: bus error: fc-list
* :ghissue:`6655`: Malware found on matplotlib components
* :ghissue:`6623`: RectangleSelector disappears after resizing
* :ghissue:`6629`: matplotlib version error
* :ghissue:`6638`: get_ticklabels returns '' in ipython/python interpreter
* :ghissue:`6631`: can't build matplotlib on smartos system(open solaris)
* :ghissue:`6562`: 2.x: Cairo backends cannot render images
* :ghissue:`6507`: custom scatter marker demo broken
* :ghissue:`6591`: DOC: update static image for interpolation_none_vs_nearest.py example
* :ghissue:`6607`: BUG: saving image to png changes colors
* :ghissue:`6587`: please copy http://matplotlib.org/devdocs/users/colormaps.html to http://matplotlib.org/users
* :ghissue:`6594`: Documentation Typo
* :ghissue:`5784`: dynamic ticking (#5588) should avoid (if possible) single ticks
* :ghissue:`6492`: mpl_toolkits.mplot3d has a null byte somewhere
* :ghissue:`5862`: Some Microsoft fonts produce unreadable EPS
* :ghissue:`6537`: bundled six 1.9.0 causes ImportError: No module named 'winreg' in Pympler
* :ghissue:`6563`: pyplot.errorbar attempts to plot 0 on a log axis in SVGs
* :ghissue:`6571`: Unexpected behavior with ttk.Notebook - graph not loaded unless tab preselected
* :ghissue:`6570`: Unexpected behavior with ttk.Notebook - graph not loaded unless tab preselected
* :ghissue:`6539`: network tests are not skipped when running tests.py with --no-network
* :ghissue:`6567`: qt_compat fails to identify PyQt5
* :ghissue:`6559`: mpl 1.5.1 requires pyqt even with a wx backend
* :ghissue:`6009`: No space before unit symbol when there is no SI prefix in ticker.EngFormatter
* :ghissue:`6528`: Fail to install matplotlib by "pip install" on SmartOS(like open solaris system)
* :ghissue:`6531`: Segmentation fault with any backend (matplotlib 1.4.3 and 1.5.1) when calling pyplot.show()
* :ghissue:`6513`: Using gray shade from string ignores alpha parameters
* :ghissue:`6477`: Savefig() to pdf renders markers differently than show()
* :ghissue:`6525`: PS export issue with custom font
* :ghissue:`6514`: LaTeX axis labels can no longer have custom fonts
* :ghissue:`2663`: Multi Cursor disable broken
* :ghissue:`6083`: Figure linewidth default in rcparams
* :ghissue:`1069`: Add a donation information page
* :ghissue:`6035`: Issue(?): head size of FancyArrowPatch changes between interactive figure and picture export
* :ghissue:`6495`: new figsize is bad for subplots with fontsize 12
* :ghissue:`6493`:  Stepfilled color cycle for background and edge different
* :ghissue:`6380`: Implicit addition of "color" to property_cycle breaks semantics
* :ghissue:`6447`: Line2D.contains does not take drawstyle into account.
* :ghissue:`6257`: option for default space between title and axes
* :ghissue:`5868`: tight_layout doesn't leave enough space between outwards ticks and axes title
* :ghissue:`5987`: Outward ticks cause labels to be clipped by default
* :ghissue:`5269`: Default changes: legend
* :ghissue:`6489`: Test errors with numpy 1.11.1rc1
* :ghissue:`5960`: Misplaced shadows when using FilteredArtistList
* :ghissue:`6452`: Please add a generic "seaborn" style
* :ghissue:`6469`: Test failures testing matplotlib 1.5.1 manylinux wheels
* :ghissue:`5854`: New cycler does not work with bar plots
* :ghissue:`5977`: legend needs logic to deal with new linestyle scaling by linewidth
* :ghissue:`6365`: Default format time series xtick labels changed
* :ghissue:`6104`: docs: latex required for PDF plotting?
* :ghissue:`6451`: Inequality error on web page http://matplotlib.org/faq/howto_faq.html
* :ghissue:`6459`: use conda already installed on appveyor
* :ghissue:`6043`: Advanced hillshading example looks strange with new defaults.
* :ghissue:`6440`: BUG: set_tick_params labelcolor should apply to offset
* :ghissue:`6458`: Wrong package name in INSTALL file
* :ghissue:`2842`: matplotlib.tests.test_basic.test_override_builtins() fails with Python >=3.4
* :ghissue:`2375`: matplotlib 1.3.0 doesn't compile with Solaris Studio 12.1 CC
* :ghissue:`2667`: matplotlib.tests.test_mathtext.test_mathtext_{cm,stix,stixsans}_{37,53}.test are failing
* :ghissue:`2243`: axes limits with aspect='equal'
* :ghissue:`1758`: y limit with dashed or dotted lines hangs with somewhat big data
* :ghissue:`5994`: Points annotation coords not working in 2.x
* :ghissue:`6444`: matplotlib.path.contains_points is a LOT slower in 1.51
* :ghissue:`5461`: Feature request: allow a default line alpha to be set in mpl.rcParams
* :ghissue:`5132`: ENH: Set the alpha value for plots in rcParams
* :ghissue:`6449`: axhline and axvline linestyle as on-off seq doesn't work if set directly in function call
* :ghissue:`6416`:  animation with 'ffmpeg' backend and 'savefig.bbox = tight' garbles video
* :ghissue:`6437`: Improperly spaced time axis
* :ghissue:`5974`: scatter is not changing color in Axes3D
* :ghissue:`6436`: clabels plotting outside of projection limb
* :ghissue:`6438`: Cant get emoji working in Pie chart legend with google app engine. Need help.
* :ghissue:`6362`: greyscale scatter points appearing blue
* :ghissue:`6301`: tricky bug in ticker due to special behaviour of numpy
* :ghissue:`6276`: Ticklabel format not preserved after editing plot limits
* :ghissue:`6173`: ``linestyle`` parameter does not support default cycler through ``None``, crashes instead.
* :ghissue:`6109`: colorbar _ticker +_locate bug
* :ghissue:`6231`: Segfault when figures are deleted in random order
* :ghissue:`6432`: micro sign doesn't show in EngFormatter
* :ghissue:`6057`: Infinite Loop: LogLocator Colorbar & update_ticks
* :ghissue:`6270`: pyplot.contour() not working with matplotlib.ticker.LinearLocator()
* :ghissue:`6058`: "Configure subplots" tool is initialized very inefficiently in the Qt backends
* :ghissue:`6363`: Change ``legend`` to accept ``alpha`` instead of (only) ``framealpha``.
* :ghissue:`6394`: Severe bug in ````imshow```` when plotting images with small values
* :ghissue:`6368`: Bug: matplotlib.pyplot.spy: does not work correctly for sparse matrices with many entries (>= 2**32)
* :ghissue:`6419`: Imshow does not copy data array but determines colormap values upon call
* :ghissue:`3615`: mouse scroll event in Gtk3 backend
* :ghissue:`3373`: add link to gtk embedding cookbook to website
* :ghissue:`6121`: opening the configure subplots menu moves the axes by a tiny amount
* :ghissue:`2511`: NavigationToolbar breaks if axes are added during use.
* :ghissue:`6349`: Down arrow on GTK3 backends selects toolbar, which eats furthur keypress events
* :ghissue:`6408`: minor ticks don't respect rcParam xtick.top / ytick.right
* :ghissue:`6398`: sudden install error with pip (pyparsing 2.1.2 related)
* :ghissue:`5819`: 1.5.1rc1: dont use absolute links in the "new updates" on the homepage
* :ghissue:`5969`: urgent bug after 1.5.0: offset of LineCollection when apply agg_filter
* :ghissue:`5767`: axes limits (in old "round_numbers" mode) affected by floating point issues
* :ghissue:`5755`: Better choice of axes offset value
* :ghissue:`5938`: possible bug with ax.set_yscale('log') when all values in array are zero
* :ghissue:`6399`: pyparsing version 2.1.2 not supported (2.1.1 works though)
* :ghissue:`5884`: ``numpy`` as no Attribute ``string0``
* :ghissue:`6395`: Deprecation warning for axes.color_cycle
* :ghissue:`6385`: Possible division by zero in new ``get_tick_space()`` methods; is rotation ignored?
* :ghissue:`6344`: Installation issue
* :ghissue:`6315`: Qt properties editor could sort lines labels using natsort
* :ghissue:`5219`: Notebook backend: possible to remove javascript/html when figure is closed?
* :ghissue:`5111`: nbagg backend captures exceptions raised by callbacks
* :ghissue:`4940`: NBAgg figure management issues
* :ghissue:`4582`: Matplotlib IPython Widget
* :ghissue:`6142`: matplotlib.ticker.LinearLocator view_limits algorithm improvement?
* :ghissue:`6326`: Unicode invisible after image saved
* :ghissue:`5980`: Gridlines on top of plot by default in 2.0?
* :ghissue:`6272`: Ability to set default scatter marker in matplotlibrc
* :ghissue:`6335`: subplots animation example is broken on OS X with qt4agg
* :ghissue:`6357`: pyplot.hist: normalization fails
* :ghissue:`6352`: clim doesn't update after draw
* :ghissue:`6353`: hist won't norm for small numbers
* :ghissue:`6343`: prop_cycle breaks keyword aliases
* :ghissue:`6226`: Issue saving figure as eps when using gouraud shaded triangulation
* :ghissue:`6330`: ticklabel_format reset to default by ScalarFormatter
* :ghissue:`4975`: Non-default ``color_cycle`` not working in Pie plot
* :ghissue:`5990`: Scatter markers do not follow new colour cycle
* :ghissue:`5577`: Handling of "next color in cycle" should be handled differently
* :ghissue:`5489`: Special color names to pull colors from the currently active color cycle
* :ghissue:`6325`: Master requires cycler 0.10.0
* :ghissue:`6278`: imshow with pgf backend does not render transparency
* :ghissue:`5945`: Figures in the notebook backend are too large following DPI changes
* :ghissue:`6332`: Animation with blit broken
* :ghissue:`6331`: matplotlib pcolormesh seems to slide some data around on the plot
* :ghissue:`6307`: Seaborn style sheets don't edit ``patch.facecolor``
* :ghissue:`6294`: Zero size ticks show up as single pixels in rendered pdf
* :ghissue:`6318`: Cannot import mpl_toolkits in Python3
* :ghissue:`6316`: Viridis exists but not in plt.cm.datad.keys()
* :ghissue:`6082`: Cannot interactively edit axes limits using Qt5 backend
* :ghissue:`6309`: Make CheckButtons based on subplots automatically
* :ghissue:`6306`: Can't show images when plt.show() was executed
* :ghissue:`2527`: Vertical alignment of text is too high
* :ghissue:`4827`: Pickled Figure Loses sharedx Properties
* :ghissue:`5998`: \math??{} font styles are ignored in 2.x
* :ghissue:`6293`: matplotlib notebook magic cells with output plots - skips next cell for computation
* :ghissue:`235`: hatch linewidth patch
* :ghissue:`5875`: Manual linestyle specification ignored if 'prop_cycle' contains 'ls'
* :ghissue:`5959`: imshow rendering issue
* :ghissue:`6237`: MacOSX agg version: doesn't redraw after keymap.grid keypress
* :ghissue:`6266`: Better fallback when color is a float
* :ghissue:`6002`: Potential bug with 'start_points' argument of 'pyplot.streamplot'
* :ghissue:`6265`: Document how to set viridis as default colormap in mpl 1.x
* :ghissue:`6258`: Rendering vector graphics: parsing polygons?
* :ghissue:`1702`: Bug in 3D histogram documentation
* :ghissue:`5937`: xticks/yticks default behaviour
* :ghissue:`4706`: Documentation - Basemap
* :ghissue:`6255`: Can't build matplotlib.ft2font in cygwin
* :ghissue:`5792`: Not easy to get colorbar tick mark locations
* :ghissue:`6233`: ImportError from Sphinx plot_directive from Cython
* :ghissue:`6235`: Issue with building docs with Sphinx 1.4.0
* :ghissue:`4383`: xkcd color names
* :ghissue:`6219`: Example embedding_in_tk.py freezes in Python3.5.1
* :ghissue:`5067`: improve whats_new entry for prop cycler
* :ghissue:`4614`: Followup items from the matplotlib 2.0 BoF
* :ghissue:`5986`: mac osx backend does not scale dashes by linewidth
* :ghissue:`4680`: Set forward=True by default when setting the figure size
* :ghissue:`4597`: use mkdtemp in _create_tmp_config_dir
* :ghissue:`3437`: Interactive save should respect 'savefig.facecolor' rcParam.
* :ghissue:`2467`: Improve default colors and layouts
* :ghissue:`4194`: matplotlib crashes on OS X when saving to JPEG and then displaying the plot
* :ghissue:`4320`: Pyplot.imshow() "None" interpolation is not supported on Mac OSX
* :ghissue:`1266`: Draggable legend results RuntimeError and AttributeError on Mac OS 10.8.1
* :ghissue:`5442`: xkcd plots rendered as regular plots on Mac OS X
* :ghissue:`2697`: Path snapping does not respect quantization scale appropriate for Retina displays
* :ghissue:`6049`: Incorrect TextPath display under interactive mode
* :ghissue:`1319`: macosx backend lacks support for cursor-type widgets
* :ghissue:`531`: macosx backend does not work with blitting
* :ghissue:`5964`: slow rendering with backend_macosx on El Capitan
* :ghissue:`5847`: macosx backend color rendering
* :ghissue:`6224`: References to non-existing class FancyBoxPatch
* :ghissue:`781`: macosx backend doesn't find fonts the same way as other backends
* :ghissue:`4271`: general colormap reverser
* :ghissue:`6201`: examples svg_histogram.html failes with UnicodeEncodeError
* :ghissue:`6212`: ENH? BUG? ``pyplot.setp``/``Artist.setp`` does not accept non-indexable iterables of handles.
* :ghissue:`4445`: Two issues with the axes offset indicator
* :ghissue:`6209`: Qt4 backend uses Qt5 backend
* :ghissue:`6136`: Feature request: configure default scatter plot marker size
* :ghissue:`6180`: Minor typos in the style sheets users' guide
* :ghissue:`5517`: "interactive example" not working with PySide
* :ghissue:`4607`: bug in font_manager.FontManager.score_family()
* :ghissue:`4400`: Setting annotation background covers arrow
* :ghissue:`596`: Add "bring window to front" functionality
* :ghissue:`4674`: Default marker edge width in plot vs. scatter
* :ghissue:`5988`: rainbow_text example is missing some text
* :ghissue:`6165`: MacOSX backend hangs drawing lines with many dashes/dots
* :ghissue:`6155`: Deprecation warnings with Dateutil 2.5
* :ghissue:`6003`: In 'pyplot.streamplot', starting points near the same streamline raise 'InvalidIndexError'
* :ghissue:`6105`: Accepting figure argument in subplot2grid
* :ghissue:`6184`: csv2rec handles dates differently to datetimes when datefirst is specified.
* :ghissue:`6164`: Unable to use PySide with gui=qt
* :ghissue:`6166`: legends do not refresh
* :ghissue:`3897`: bug: inconsistent types accepted in DateLocator subclasses
* :ghissue:`6160`: EPS issues with rc parameters used in seaborn library on Win 8.1
* :ghissue:`6163`: Can´t make matplotlib run in my computer
* :ghissue:`5331`: Boxplot with zero IQR sets whiskers to max and min and leaves no outliers
* :ghissue:`5575`: plot_date() ignores timezone
* :ghissue:`6143`: drawstyle accepts anything as default rather than raising
* :ghissue:`6151`: Matplotlib 1.5.1 ignores annotation_clip parameter
* :ghissue:`6147`: colormaps issue
* :ghissue:`5916`: Headless get_window_extent or equivalent
* :ghissue:`6141`: Matplotlib subplots and datetime x-axis functionality not working as intended?
* :ghissue:`6138`: No figure shows, no error
* :ghissue:`6134`: Cannot plot a line of width=1 without antialiased
* :ghissue:`6120`: v2.x failures on travis
* :ghissue:`6092`: %matplotlib notebook broken with current matplotlib master
* :ghissue:`1235`: Legend placement bug
* :ghissue:`2499`: Showing np.uint16 images of the form (h,w,3) is broken
* :ghissue:`5479`: Table: auto_set_column_width not working
* :ghissue:`6028`: Appearance of non-math hyphen changes with math in text
* :ghissue:`6113`: ValueError after moving legend  and rcParams.update
* :ghissue:`6111`: patches fails when data are array, not list
* :ghissue:`6108`: Plot update issue within event callback for multiple updates
* :ghissue:`6069`: imshow no longer correctly handles 'bad' (``nan``) values
* :ghissue:`6103`: ticklabels empty when not interactive
* :ghissue:`6084`: Despined figure is cropped
* :ghissue:`6067`: pyplot.savefig doesn't expand ~ (tilde) in path
* :ghissue:`4754`: Change default color cycle
* :ghissue:`6063`: Axes.relim() seems not to work when copying Line2D objects
* :ghissue:`6065`: Proposal to change color -- 'indianred'
* :ghissue:`6056`: quiver plot in polar projection - how to make the quiver density latitude-dependent ?
* :ghissue:`6051`: Matplotlib v1.5.1 apparently not compatible with python-dateutil 2.4.2
* :ghissue:`5513`: Call get_backend in pylab_setup
* :ghissue:`5983`: Option to Compress Graphs for pgf-backend
* :ghissue:`5895`: Polar Projection PDF Issue
* :ghissue:`5948`: tilted line visible in generated pdf file
* :ghissue:`5737`: matplotlib 1.5 compatibility with wxPython
* :ghissue:`5645`: Missing line in a self-sufficient example in navigation_toolbar.rst :: a minor bug in docs
* :ghissue:`6037`: Matplotlib xtick appends .%f after %H:%M%:%S on chart
* :ghissue:`6025`: Exception in Tkinter/to_rgb with new colormaps
* :ghissue:`6034`: colormap name is broken for ListedColormap?
* :ghissue:`5982`: Styles need update after default style changes
* :ghissue:`6017`: Include tests.py in archive of release
* :ghissue:`5520`: 'nearest' interpolation not working with low dpi
* :ghissue:`4280`: imsave reduces 1row from the image
* :ghissue:`3057`: DPI-connected bug of imshow when using multiple masked arrays
* :ghissue:`5490`: Don't interpolate images in RGB space
* :ghissue:`5996`: 2.x: Figure.add_axes(..., facecolor='color') does not set axis background colour
* :ghissue:`4760`: Default linewidth thicker than axes linewidth
* :ghissue:`2698`: ax.text() fails to draw a box if the text content is full of blank spaces and linefeeds.
* :ghissue:`3948`: a weird thing in the source code comments
* :ghissue:`5921`: test_backend.pgf.check_for(texsystem) does not do what it says...
* :ghissue:`4295`: Draggable annotation position wrong with negative x/y
* :ghissue:`1986`: Importing pyplot messes with command line argument parsing
* :ghissue:`5885`: matplotlib stepfilled histogram breaks at the value 10^-1 on xubuntu
* :ghissue:`5050`: pandas v0.17.0rc1
* :ghissue:`3658`: axes.locator_params fails with LogLocator (and most Locator subclasses)
* :ghissue:`3742`: Square plots
* :ghissue:`3900`: debugging Segmentation fault with Qt5 backend
* :ghissue:`4192`: Error when color value is None
* :ghissue:`4210`: segfault: fill_between with Python3
* :ghissue:`4325`: FancyBboxPatch wrong size
* :ghissue:`4340`: Histogram gap artifacts
* :ghissue:`5096`: Add xtick.top.visible, xtick.bottom.visible, ytick.left.visible, ytick.right.visible to rcParams
* :ghissue:`5120`: custom axis scale doesn't work in 1.4.3
* :ghissue:`5212`: shifted(?) bin positions when plotting multiple histograms at the same time
* :ghissue:`5293`: Qt4Agg: RuntimeError: call __init__ twice
* :ghissue:`5971`: Add support for PySide2 (Qt5)
* :ghissue:`5993`: Basemap readshapefile should read shapefile for the long/lat specified in the Basemap instance.
* :ghissue:`5991`: basemap crashes with no error message when passed numpy nan's
* :ghissue:`5883`: New colormaps : Inferno, Viridis, ...
* :ghissue:`5841`: extra label for non-existent tick
* :ghissue:`4502`: Default style proposal: outward tick marks
* :ghissue:`875`: Replace "jet" as the default colormap
* :ghissue:`5047`: Don't draw end caps on error bars by default
* :ghissue:`4700`: Overlay blend mode
* :ghissue:`4671`: Change default legend location to 'best'.
* :ghissue:`5419`: Default setting of figure transparency in NbAgg is a performance problem
* :ghissue:`4815`: Set default axis limits in 2D-plots to the limits of the data
* :ghissue:`4854`: set numpoints to 1
* :ghissue:`5917`: improved dash styles
* :ghissue:`5900`: Incorrect Image Tutorial Inline Sample Code
* :ghissue:`5965`: xkcd example in gallery
* :ghissue:`5616`: Better error message if no animation writer is available
* :ghissue:`5920`: How to rotate secondary y axis label so it doesn't overlap with y-ticks, matplotlib
* :ghissue:`5966`: SEGFAULT if ``pyplot`` is imported
* :ghissue:`5967`: savefig SVG and PDF output for scatter plots is excessively complex, crashses Inkscape
* :ghissue:`1943`: legend doesn't work with stackplot
* :ghissue:`5923`: Windows usetex=True error in long usernames
* :ghissue:`5940`: KeyError: 'getpwuid(): uid not found: 5001'
* :ghissue:`5748`: Windows test failures on appveyor
* :ghissue:`5944`: Notebook backend broken on Master
* :ghissue:`5946`: Calling subplots_adjust breaks savefig output
* :ghissue:`5929`: Fallback font doesn't work on windows?
* :ghissue:`5925`: Data points beyond axes range plotted when saved to SVG
* :ghissue:`5918`: Pyplot.savefig is very slow with some combinations of data/ylim scales
* :ghissue:`5919`: Error when trying to import matplotlib into IPython notebook
* :ghissue:`5803`: Barbs broken
* :ghissue:`5846`: setupext.py: problems parsing setup.cfg (not updated to changes in configparser)
* :ghissue:`5309`: Differences between function and keywords for savefig.bbox and axes.facecolor
* :ghissue:`5889`: Factual errors in HowTo FAQ Box Plot Image
* :ghissue:`5618`: New rcParams requests
* :ghissue:`5810`: Regression in test_remove_shared_axes
* :ghissue:`5281`: plt.tight_layout(pad=0) cuts away outer ticks
* :ghissue:`5909`: The documentation for LinearLocator's presets keyword is unclear
* :ghissue:`5864`: mathtext mishandling of certain exponents
* :ghissue:`5869`: doc build fails with mpl-1.5.1 and sphinx-1.3.4 (sphinx-1.3.3 is fine)
* :ghissue:`5835`: gridspec.Gridspec doesn't check for consistency in arguments
* :ghissue:`5867`: No transparency in \*.pgf file when using pgf Backend.
* :ghissue:`5863`: \left( ... \right) are too small
* :ghissue:`5850`: prop_cycler for custom dashes -- linestyle such as (<offset>, (<on>, <off>)) throws error
* :ghissue:`5861`: Marker style request
* :ghissue:`5851`: Bar and box plots use the 'default' matplotlib colormap, even if the style is changed
* :ghissue:`5857`: FAIL: matplotlib.tests.test_coding_standards.test_pep8_conformance_examples
* :ghissue:`5831`: tests.py is missing from pypi tarball
* :ghissue:`5829`: test_rasterize_dpi fails with 1.5.1
* :ghissue:`5843`: what is  the source  code of ax.pcolormesh(T, R, Z,vmin=0,vmax=255,cmap='jet') ?
* :ghissue:`5799`: mathtext kerning around comma
* :ghissue:`2841`: There is no set_linestyle_cycle in the matplotlib axes API
* :ghissue:`5821`: Consider using an offline copy of Raleway font
* :ghissue:`5822`: FuncAnimation.save() only saving 1 frame
* :ghissue:`5449`: Incomplete dependency list for installation from source
* :ghissue:`5793`: GTK backends
* :ghissue:`5814`: Adding colorbars to row subplots doesn't render the main plots when saving to .eps in 1.5.0
* :ghissue:`5816`: matplotlib.pyplot.boxplot ignored showmeans keyword
* :ghissue:`5086`: Default date format for axis formatting
* :ghissue:`4808`: AutoDateFormatter shows too much precision
* :ghissue:`5812`: Widget event issue
* :ghissue:`5794`: --no-network not recognized as valid option for tests.py
* :ghissue:`5801`: No such file or directory: '/usr/share/matplotlib/stylelib'
* :ghissue:`5777`: Using default style raises warnings about non style parameters
* :ghissue:`5738`: Offset text should be computed based on lowest and highest ticks, not actual axes limits
* :ghissue:`5403`: Document minimal MovieWriter sub-class
* :ghissue:`5558`: The link to the John Hunter Memorial fund is a 404
* :ghissue:`5757`: Several axes_grid1 and axisartist examples broken on master
* :ghissue:`5557`: plt.hist throws KeyError when passed a pandas.Series without 0 in index
* :ghissue:`5550`: Plotting datetime values from Pandas dataframe
* :ghissue:`4855`: Limit what ``style.use`` can affect?
* :ghissue:`5765`: import matplotlib._png as _png ImportError: libpng16.so.16: cannot open shared object
* :ghissue:`5753`: Handling of zero in log shared axes depends on whether axes are shared
* :ghissue:`5756`: 3D rendering, scatterpoints disapear near edges of surfaces
* :ghissue:`5747`: Figure.suptitle does not respect ``size`` argument
* :ghissue:`5641`: plt.errorbar error with empty list
* :ghissue:`5476`: annotate doesn't trigger redraw
* :ghissue:`5572`: Matplotlib 1.5  broken_barh fails on empty data.
* :ghissue:`5089`: axes.properties calls get_axes internally
* :ghissue:`5745`: Using internal qhull despite the presence of pyqhull installed in the system
* :ghissue:`5744`: cycler is required, is missing, yet build succeeds.
* :ghissue:`5592`: Problem with _init_func in ArtistAnimation
* :ghissue:`5729`: Test matplotlib.tests.test_backend_svg.test_determinism fails on OSX in virtual envs.
* :ghissue:`4756`: font_manager.py takes multiple seconds to import
* :ghissue:`5435`: Unable to upgrade matplotlib 1.5.0 through pip
* :ghissue:`5636`: Generating legend from figure options panel of qt backend raise exception for large number of plots
* :ghissue:`5365`: Warning in test_lines.test_nan_is_sorted
* :ghissue:`5646`: Version the font cache
* :ghissue:`5692`: Can't remove StemContainer
* :ghissue:`5635`: RectangleSelector creates not wanted lines in axes
* :ghissue:`5427`: BUG? Normalize modifies pandas Series inplace
* :ghissue:`5693`: Invalid caching of long lines with nans
* :ghissue:`5705`: doc/users/plotting/examples/axes_zoom_effect.py is not a Python file
* :ghissue:`4359`: savefig crashes with malloc error on os x
* :ghissue:`5715`: Minor error in set up fork
* :ghissue:`5687`: Segfault on plotting with PySide as backend.qt4
* :ghissue:`5708`: Segfault with Qt4Agg backend in 1.5.0
* :ghissue:`5704`: Issue with xy and xytext
* :ghissue:`5673`: colorbar labelling bug (1.5 regression)
* :ghissue:`4491`: Document how to get a framework build in a virtual env
* :ghissue:`5468`: axes selection in axes editor
* :ghissue:`5684`: AxesGrid demo exception with LogNorm: 'XAxis' object has no attribute 'set_scale'
* :ghissue:`5663`: AttributeError: 'NoneType' object has no attribute 'canvas'
* :ghissue:`5573`: Support HiDPI (retina) displays in docs
* :ghissue:`5680`: SpanSelector span_stays fails with use_blit=True
* :ghissue:`5679`: Y-axis switches to log scale when an X-axis is shared multiple times.
* :ghissue:`5655`: Problems installing basemap behind a proxy
* :ghissue:`5670`: Doubling of coordinates in polygon clipping
* :ghissue:`4725`: change set_adjustable for share axes with aspect ratio of 1
* :ghissue:`5488`: The default number of ticks should be based on the length of the axis
* :ghissue:`5543`: num2date ignoring tz in v1.5.0
* :ghissue:`305`: Change canvas.print_figure default resolution
* :ghissue:`5660`: Cannot raise FileNotFoundError in python2
* :ghissue:`5658`: A way to remove the image of plt.figimage()?
* :ghissue:`5495`: Something fishy in png reading
* :ghissue:`5549`: test_streamplot:test_colormap test broke unintentionally
* :ghissue:`5381`: HiDPI support in Notebook backend
* :ghissue:`5531`: test_mplot3d:test_quiver3d broke unintentionally
* :ghissue:`5530`: test_axes:test_polar_unit broke unintentionally
* :ghissue:`5525`: Comparison failure in text_axes:test_phase_spectrum_freqs
* :ghissue:`5650`: Wrong backend selection with PyQt4
* :ghissue:`5649`: Documentation metadata (release version) does not correspond with some of the 'younger' documentation content
* :ghissue:`5648`: Some tests require non-zero tolerance
* :ghissue:`3980`: zoom in wx with retnia behaves badly
* :ghissue:`5642`: Mistype in pyplot_scales.py of pyplot_tutorial.rst :: a minor bug in docs
* :ghissue:`3316`: wx crashes on exit if figure not shown and not explicitly closed
* :ghissue:`5624`: Cannot manually close matplotlib plot window in Mac OS X Yosemite
* :ghissue:`4891`: Better auto-selection of axis limits
* :ghissue:`5633`: No module named externals
* :ghissue:`5634`: No module named 'matplotlib.tests'
* :ghissue:`5473`: Strange OS warning when import pyplot after upgrading to 1.5.0
* :ghissue:`5524`: Change in colorbar extensions
* :ghissue:`5627`: Followup for Windows CI stuff
* :ghissue:`5613`: Quiverkey() positions arrow incorrectly with labelpos 'N' or 'S'
* :ghissue:`5615`: tornado now a requirement?
* :ghissue:`5582`: FuncAnimation crashes the interpreter (win7, 64bit)
* :ghissue:`5610`: Testfailures on windows
* :ghissue:`5595`: automatically build windows conda packages and wheels in master
* :ghissue:`5535`: test_axes:test_rc_grid image comparison test has always been broken
* :ghissue:`4396`: Qt5 is not mentioned in backends list in doc
* :ghissue:`5205`: pcolor does not handle non-array C data
* :ghissue:`4839`: float repr in axes parameter editing window (aka the green tick button)
* :ghissue:`5542`: Bad superscript positioning for some fonts
* :ghissue:`3791`: Update colormap examples.
* :ghissue:`4679`: Relationship between line-art markers and the markeredgewidth parameter
* :ghissue:`5601`: Scipy/matplotlib recipe with plt.connect() has trouble in python 3 (AnnoteFinder)
* :ghissue:`4211`: Axes3D quiver: variable length arrows
* :ghissue:`773`: mplot3d enhancement
* :ghissue:`395`: need 3D examples for tricontour and tricontourf
* :ghissue:`186`: Axes3D with PolyCollection broken
* :ghissue:`178`: Incorrect mplot3d contourf rendering
* :ghissue:`5508`: Animation.to_html5_video requires python3 base64 module
* :ghissue:`5576`: Improper reliance upon pkg-config when C_INCLUDE_PATH is set
* :ghissue:`5369`: Change in zorder of streamplot between 1.3.1 and 1.4.0
* :ghissue:`5569`: Stackplot does not handle NaNs
* :ghissue:`5565`: label keyword is not interpreted proporly in errorbar() for pandas.DataFrame-like objects
* :ghissue:`5561`: interactive mode doesn't display images with standard python interpreter
* :ghissue:`5559`: Setting window titles when in interactive mode
* :ghissue:`5554`: Cropping text to axes
* :ghissue:`5545`: EllipseCollection renders incorrectly when passed a sequence of widths
* :ghissue:`5475`: artist picker tolerance has no effect
* :ghissue:`5529`: Wrong image/code for legend_demo (pylab)
* :ghissue:`5139`: plt.subplots for already existing Figure
* :ghissue:`5497`: violin{,plot} return value
* :ghissue:`5441`: boxplot rcParams are not in matplotlibrc.template
* :ghissue:`5522`: axhline fails on custom scale example
* :ghissue:`5528`: $\rho$ in text for plots erroring
* :ghissue:`4799`: Probability axes scales
* :ghissue:`5487`: Trouble importing image_comparison decorator in v1.5
* :ghissue:`5464`: figaspect not working with numpy floats
* :ghissue:`4487`: Should default hist() bins be changed in 2.0?
* :ghissue:`5499`: UnicodeDecodeError in IPython Notebook caused by negative numbers in plt.legend()
* :ghissue:`5498`: Labels' collisions while plotting named DataFrame iterrows
* :ghissue:`5491`: clippedline.py example should be removed
* :ghissue:`5482`: RuntimeError: could not open display
* :ghissue:`5481`: value error : unknown locale: UTF-8
* :ghissue:`4780`: Non-interactive backend calls draw more than 100 times
* :ghissue:`5470`: colorbar values could take advantage of offsetting and/or scientific notation
* :ghissue:`5471`: FuncAnimation video saving results in one frame file
* :ghissue:`5457`: Example of new colormaps is misleading
* :ghissue:`3920`: Please fix pip install, so that plt.show() etc works correctly
* :ghissue:`5418`: install backend gtk in Cygwin
* :ghissue:`5368`: New axes.set_prop_cycle method cannot handle any generic iterable
* :ghissue:`5446`: Tests fail to run (killed manually after 7000 sec)
* :ghissue:`5225`: Rare race condition in makedirs with parallel processes
* :ghissue:`5444`: \overline and subscripts/superscripts in mathtext
* :ghissue:`4859`: Call ``tight_layout()`` by default
* :ghissue:`5429`: Segfault in matplotlib.tests.test_image:test_get_window_extent_for_AxisImage on python3.5
* :ghissue:`5431`: Matplotlib 1.4.3 broken on Windows
* :ghissue:`5409`: Match zdata cursor display scalling with colorbar ?
* :ghissue:`5128`: ENH: Better default font
* :ghissue:`5420`: [Mac OS X 10.10.5] Macports install error :unknown locale: UTF-8
* :ghissue:`3867`: OSX compile broken since CXX removal (conda only?)
* :ghissue:`5411`: XKCD style fails except for inline mode
* :ghissue:`5406`: Hangs on OS X 10.11.1: No such file or directory: '~/.matplotlib/fontList.json'
* :ghissue:`3116`: mplot3d: argument checking in plot_surface should be improved.
* :ghissue:`347`: Faster Text drawing needed
* :ghissue:`5399`: FuncAnimation w/o init_func breaks when saving
* :ghissue:`5395`: Style changes doc has optimistic release date
* :ghissue:`5393`: wrong legend in errorbar plot for pandas series
* :ghissue:`5396`: fill_between() with gradient
* :ghissue:`5221`: infinite range for hist(histtype="step")
* :ghissue:`4901`: Error running double pendulum animation example
* :ghissue:`3314`: assert mods.pop(0) == 'tests' errors for multiprocess tests on OSX
* :ghissue:`5337`: Remove --nocapture from nosetests on .travis.yml?
* :ghissue:`5378`: errorbar fails with pandas data frame
* :ghissue:`5367`: histogram and digitize do not agree on the definition of a bin
* :ghissue:`5314`: ValueError: insecure string pickle
* :ghissue:`5347`: Problem with importing matplotlib.animation
* :ghissue:`4788`: Modified axes patch will not re-clip artists
* :ghissue:`4968`: Lasso-ing in WxAgg causes flickering of the entire figure
